@@ -21,12 +21,16 @@
  *
  */
 
-app.run(['$rootScope', '$window',
-	function ($rootScope, $window) {
+app.run(['$document', '$rootScope', '$window',
+	function ($document, $rootScope, $window) {
 		'use strict';
 
 		$rootScope.baseUrl = $window.location.origin +
 			$window.location.pathname +
 			'v1/';
+
+		$document.click(function (event) {
+			$rootScope.$broadcast('documentClicked', event);
+		});
 	}
 ]);
