@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendář",
-    "New event" : "Nová událost",
-    "Global" : "Globální",
-    "None" : "Žádné",
-    "Attendees" : "Účastníci",
-    "Reminders" : "Připomínky",
-    "Does not repeat" : "Neopakuje se",
-    "Daily" : "Denně",
-    "Weekly" : "Týdně",
-    "Every Weekday" : "Každý všední den",
-    "Bi-weekly" : "Jednou za dva týdny",
-    "Monthly" : "Měsíčně",
-    "Yearly" : "Ročně",
-    "never" : "nikdy",
-    "by occurances" : "při příležitostech",
-    "by date" : "podle data",
-    "by monthday" : "podle dne v měsíci",
-    "by weekday" : "podle dne v týdnu",
-    "by events date" : "podle data události",
-    "by yearday(s)" : "po dni (dnech)",
-    "by week no(s)" : "podle čísel týdnů",
-    "by day and month" : "podle dne a měsíce",
-    "Monday" : "Pondělí",
-    "Tuesday" : "Úterý",
-    "Wednesday" : "Středa",
-    "Thursday" : "Čtvrtek",
-    "Friday" : "Pátek",
-    "Saturday" : "Sobota",
-    "Sunday" : "Neděle",
-    "Other" : "Jiný",
     "Individual" : "Individuální",
     "Group" : "Skupina",
     "Resource" : "Zdroj",
@@ -39,9 +10,23 @@ OC.L10N.register(
     "Required" : "Vyžadován",
     "Optional" : "Nepovinně",
     "Does not attend" : "Neúčastní se",
+    "New event" : "Nová událost",
+    "Attendees" : "Účastníci",
+    "Reminders" : "Připomínky",
+    "Repeating" : "Opakování",
     "When shared show full event" : "Po nasdílení zobrazit celou událost",
     "When shared show only busy" : "Po nasdílení zobrazit jako zaneprázdněné",
     "When shared hide this event" : "Po nasdílení skrýt tuto událost",
+    "Please add a title!" : "Zadejte prosím název!",
+    "Please select a calendar!" : "Vyberte prosím kalendář!",
+    "Global" : "Globální",
+    "None" : "Žádné",
+    "Every day" : "Každý den",
+    "Every week" : "Každý týden",
+    "Every month" : "Každý měsíc",
+    "Every year" : "Každý rok",
+    "never" : "nikdy",
+    "after" : "po",
     "At time of event" : "V čase události",
     "5 minutes before" : "5 minut předem",
     "10 minutes before" : "10 minut předem",
@@ -58,10 +43,10 @@ OC.L10N.register(
     "hours" : "hodiny",
     "days" : "dnech",
     "week" : "týden",
-    "Before" : "Před",
-    "After" : "Po",
-    "Start" : "Spuštění",
-    "End" : "Konec",
+    "before" : "před",
+    "start" : "začátek",
+    "end" : "konec",
+    "Editing reminders of uknown type not supported." : "Úprava připomínek neznámého typu není podporována. ",
     "Week {number} of {year}" : "Týden {number} rok {year}",
     "Successfully imported" : "Úspěšně importován",
     "Partially imported, 1 failure" : "Částečně importován, 1 chyba",
@@ -77,14 +62,31 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} při konci události",
     "{type} at {time}" : "{type} v {time}",
     "{calendar} shared by {owner}" : "{calendar} sdílen uživatelem {owner}",
+    "Title of the Event" : "Název události",
+    "starts" : "začíná",
+    "ends" : "končí",
+    "All day Event" : "Celodenní událost",
+    "Location" : "Umístění",
+    "Delete" : "Smazat",
+    "Cancel" : "Zrušit",
+    "More ..." : "Více ...",
+    "Create" : "Vytvořit",
+    "Update" : "Aktualizovat",
+    "Close" : "Zavřít",
+    "Description" : "Popis",
+    "Export" : "Exportovat",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Kalendář v současné chvíli nemůže nabídnout podporu pro funkci \"asset pipeline\" (spojení a komprese css a js souborů).",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Prosím, kontaktujte Vašeho administrátora a zeptejte se ho na zrušení funkce \"asset-pipeline.enabled\" v konfiguračním souboru.",
     "Day" : "Den",
     "Week" : "Týden",
     "Month" : "Měsíc",
     "Today" : "Dnes",
     "Share Calendar" : "Sdílet kalendář",
+    "More" : "Více",
+    "Edit" : "Upravit",
+    "CalDAV" : "CalDAV",
     "group" : "skupina",
     "New Calendar" : "Nový kalendář",
-    "Create" : "Vytvořit",
     "Subscriptions" : "Odběry",
     "New Subscription" : "Nový odběr",
     "Url" : "URL",
@@ -95,26 +97,19 @@ OC.L10N.register(
     "Type" : "Typ",
     "Relative" : "Relativní",
     "Absolute" : "Absolutní",
-    "Date" : "Datum",
     "Repeat" : "Opakovat",
     "times every" : "krát každých",
     "Add" : "Přidat",
+    "E-Mail address of attendee" : "Emailová adresa účastníka",
     "Please add your email address in the personal settings in order to add attendees." : "Zadejte prosím svou emailovou adresu v osobním nastavení, abyste mohli přidávat účastníky.",
-    "Title of the Event" : "Název události",
     "from" : "od",
     "to" : "do",
-    "All day Event" : "Celodenní událost",
-    "Location" : "Umístění",
-    "starts" : "začíná",
-    "ends" : "končí",
-    "Delete" : "Smazat",
-    "Cancel" : "Zrušit",
-    "More ..." : "Více ...",
-    "Update" : "Aktualizovat",
-    "Close" : "Zavřít",
-    "Interval" : "Interval",
-    "Description" : "Popis",
-    "Export" : "Exportovat",
+    "This event's repeating rule is not supported yet." : "Pravidlo opakování této události není ještě podporováno.",
+    "Support for advanced rules will be added with subsequent updates." : "Podpora pokročilých pravidel bude přidána v následujících aktualizacích.",
+    "Reset repeating rule" : "Resetovat pravidlo opakování",
+    "Repeat every ..." : "Opakovat každé ...",
+    "end repeat ..." : "ukončit opakování ...",
+    "times" : "krát",
     "Import Calendars" : "Importovat kalendáře",
     "Import canceled" : "Import zrušen",
     "Analyzing calendar" : "Analýza kalendáře",
