@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
-    "New event" : "Neuer Termin",
-    "Global" : "Global",
-    "None" : "Keine",
-    "Attendees" : "Teilnehmer",
-    "Reminders" : "Erinnerungen",
-    "Does not repeat" : "einmalig",
-    "Daily" : "täglich",
-    "Weekly" : "wöchentlich",
-    "Every Weekday" : "jeden Wochentag",
-    "Bi-weekly" : "jede zweite Woche",
-    "Monthly" : "monatlich",
-    "Yearly" : "jährlich",
-    "never" : "niemals",
-    "by occurances" : "nach Terminen",
-    "by date" : "nach Datum",
-    "by monthday" : "an einem Monatstag",
-    "by weekday" : "an einem Wochentag",
-    "by events date" : "nach Datum des Termins",
-    "by yearday(s)" : "nach Tag des Jahres",
-    "by week no(s)" : "von Woche (n) der",
-    "by day and month" : "nach Tag und Monat",
-    "Monday" : "Montag",
-    "Tuesday" : "Dienstag",
-    "Wednesday" : "Mittwoch",
-    "Thursday" : "Donnerstag",
-    "Friday" : "Freitag",
-    "Saturday" : "Samstag",
-    "Sunday" : "Sonntag",
-    "Other" : "Andere",
     "Individual" : "individuell",
     "Group" : "Gruppe",
     "Resource" : "Ressource",
@@ -39,9 +10,25 @@ OC.L10N.register(
     "Required" : "erforderlich",
     "Optional" : "optional",
     "Does not attend" : "Nimmt nicht teil",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Sie sind in einer unbekannten Zeitzone ({tz}), auf UTC wird geändert",
+    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
+    "New event" : "Neuer Termin",
+    "Attendees" : "Teilnehmer",
+    "Reminders" : "Erinnerungen",
+    "Repeating" : "Wiederholen",
     "When shared show full event" : "wenn geteilt, zeige den vollständigen Termin an",
     "When shared show only busy" : "wenn geteilt, zeige nur 'beschäftigt'",
     "When shared hide this event" : "wenn geteilt, zeige den Termin nicht an",
+    "Please add a title!" : "Bitte fügen Sie einen Titel hinzu!",
+    "Please select a calendar!" : "Bitte wählen Sie einen Kalender aus!",
+    "Global" : "Global",
+    "None" : "Keine",
+    "Every day" : "jeden Tag",
+    "Every week" : "jede Woche",
+    "Every month" : "jeden Monat",
+    "Every year" : "jedes Jahr",
+    "never" : "niemals",
+    "after" : "nach",
     "At time of event" : "Zum Zeitpunkt des Termins",
     "5 minutes before" : "5 Minuten vor",
     "10 minutes before" : "10 Minuten vor",
@@ -58,10 +45,10 @@ OC.L10N.register(
     "hours" : "Stunden",
     "days" : "Tage",
     "week" : "Woche",
-    "Before" : "vor",
-    "After" : "nach",
-    "Start" : "Start",
-    "End" : "Ende",
+    "before" : "vor",
+    "start" : "Start",
+    "end" : "Ende",
+    "Editing reminders of uknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
     "Week {number} of {year}" : "Woche {number} aus {year}",
     "Successfully imported" : "Erfolgreich importiert",
     "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
@@ -77,14 +64,31 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} am Ende der Veranstaltung",
     "{type} at {time}" : "{type} um {time}",
     "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
+    "Title of the Event" : "Bezeichnung des Termins",
+    "starts" : "Beginnt",
+    "ends" : "endet",
+    "All day Event" : "Ganztägiger Termin",
+    "Location" : "Ort",
+    "Delete" : "Löschen",
+    "Cancel" : "Abbrechen",
+    "More ..." : "Mehr...",
+    "Create" : "Erstellen",
+    "Update" : "Update durchführen",
+    "Close" : "Schließen",
+    "Description" : "Beschreibung",
+    "Export" : "Exportieren",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Durch einen vorgeschalteten Fehler, ist der Kalender zur Zeit nicht in der Lage eine Unterstützung für die Asset Pipeline -Funktion zur Verfügung zu stellen.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktieren Sie ihren Administrator und bitten Sie ihn, die \"asset-pipeline.enabled\" Konfiguration zu deaktivieren.",
     "Day" : "Tag",
     "Week" : "Woche",
     "Month" : "Monat",
     "Today" : "Heute",
     "Share Calendar" : "Kalender freigeben",
+    "More" : "Mehr",
+    "Edit" : "Bearbeiten",
+    "CalDAV" : "CalDAV",
     "group" : "Gruppe",
     "New Calendar" : "Neuer Kalender",
-    "Create" : "Erstellen",
     "Subscriptions" : "Abonnements",
     "New Subscription" : "neues Abonnement",
     "Url" : "Url",
@@ -95,27 +99,19 @@ OC.L10N.register(
     "Type" : "Typ",
     "Relative" : "Relativ",
     "Absolute" : "Absolut",
-    "Date" : "Datum",
     "Repeat" : "Wiederholen",
     "times every" : "mal pro",
     "Add" : "Hinzufügen",
     "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
     "Please add your email address in the personal settings in order to add attendees." : "Bitte fügen Sie ihre E-Mail-Adresse in den persönlichen Einstellungen hinzu, um Teilnehmer hinzufügen zu können. ",
-    "Title of the Event" : "Bezeichnung des Termins",
     "from" : "von",
     "to" : "an",
-    "All day Event" : "Ganztägiger Termin",
-    "Location" : "Ort",
-    "starts" : "Beginnt",
-    "ends" : "endet",
-    "Delete" : "Löschen",
-    "Cancel" : "Abbrechen",
-    "More ..." : "Mehr...",
-    "Update" : "Update durchführen",
-    "Close" : "Schließen",
-    "Interval" : "Intervall",
-    "Description" : "Beschreibung",
-    "Export" : "Exportieren",
+    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Termins wird noch nicht unterstützt.",
+    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Updates hinzugefügt.",
+    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
+    "Repeat every ..." : "wiederhole jeden ...",
+    "end repeat ..." : "Wiederholung beenden ...",
+    "times" : "Zeiten",
     "Import Calendars" : "Kalender importieren",
     "Import canceled" : "Importieren abgebrochen",
     "Analyzing calendar" : "Kalender analysieren",
