@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendar",
-    "New event" : "New event",
-    "Global" : "Global",
-    "None" : "None",
-    "Attendees" : "Attendees",
-    "Reminders" : "Reminders",
-    "Does not repeat" : "Does not repeat",
-    "Daily" : "Daily",
-    "Weekly" : "Weekly",
-    "Every Weekday" : "Every Weekday",
-    "Bi-weekly" : "Bi-weekly",
-    "Monthly" : "Monthly",
-    "Yearly" : "Yearly",
-    "never" : "never",
-    "by occurances" : "by occurances",
-    "by date" : "by date",
-    "by monthday" : "by day of month",
-    "by weekday" : "by weekday",
-    "by events date" : "by event's date",
-    "by yearday(s)" : "by yearday(s)",
-    "by week no(s)" : "by week no(s)",
-    "by day and month" : "by day and month",
-    "Monday" : "Monday",
-    "Tuesday" : "Tuesday",
-    "Wednesday" : "Wednesday",
-    "Thursday" : "Thursday",
-    "Friday" : "Friday",
-    "Saturday" : "Saturday",
-    "Sunday" : "Sunday",
-    "Other" : "Other",
     "Individual" : "Individual",
     "Group" : "Group",
     "Resource" : "Resource",
@@ -39,9 +10,23 @@ OC.L10N.register(
     "Required" : "Required",
     "Optional" : "Optional",
     "Does not attend" : "Does not attend",
+    "New event" : "New event",
+    "Attendees" : "Attendees",
+    "Reminders" : "Reminders",
+    "Repeating" : "Repeating",
     "When shared show full event" : "When shared show full event",
     "When shared show only busy" : "When shared show only busy",
     "When shared hide this event" : "When shared hide this event",
+    "Please add a title!" : "Please add a title!",
+    "Please select a calendar!" : "Please select a calendar!",
+    "Global" : "Global",
+    "None" : "None",
+    "Every day" : "Every day",
+    "Every week" : "Every week",
+    "Every month" : "Every month",
+    "Every year" : "Every year",
+    "never" : "never",
+    "after" : "after",
     "At time of event" : "At time of event",
     "5 minutes before" : "5 minutes before",
     "10 minutes before" : "10 minutes before",
@@ -58,10 +43,10 @@ OC.L10N.register(
     "hours" : "hours",
     "days" : "days",
     "week" : "week",
-    "Before" : "Before",
-    "After" : "After",
-    "Start" : "Start",
-    "End" : "End",
+    "before" : "before",
+    "start" : "start",
+    "end" : "end",
+    "Editing reminders of uknown type not supported." : "Editing reminders of unknown type not supported.",
     "Week {number} of {year}" : "Week {number} of {year}",
     "Successfully imported" : "Successfully imported",
     "Partially imported, 1 failure" : "Partially imported, 1 failure",
@@ -77,14 +62,30 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} at the event's end",
     "{type} at {time}" : "{type} at {time}",
     "{calendar} shared by {owner}" : "{calendar} shared by {owner}",
+    "Title of the Event" : "Title of the Event",
+    "starts" : "starts",
+    "ends" : "ends",
+    "All day Event" : "All day Event",
+    "Location" : "Location",
+    "Delete" : "Delete",
+    "Cancel" : "Cancel",
+    "More ..." : "More ...",
+    "Create" : "Create",
+    "Update" : "Update",
+    "Close" : "Close",
+    "Description" : "Description",
+    "Export" : "Export",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option.",
     "Day" : "Day",
     "Week" : "Week",
     "Month" : "Month",
     "Today" : "Today",
     "Share Calendar" : "Share Calendar",
+    "More" : "More",
+    "Edit" : "Edit",
     "group" : "group",
     "New Calendar" : "New Calendar",
-    "Create" : "Create",
     "Subscriptions" : "Subscriptions",
     "New Subscription" : "New Subscription",
     "Url" : "URL",
@@ -95,27 +96,19 @@ OC.L10N.register(
     "Type" : "Type",
     "Relative" : "Relative",
     "Absolute" : "Absolute",
-    "Date" : "Date",
     "Repeat" : "Repeat",
     "times every" : "times every",
     "Add" : "Add",
     "E-Mail address of attendee" : "E-Mail address of attendee",
     "Please add your email address in the personal settings in order to add attendees." : "Please add your email address in the personal settings in order to add attendees.",
-    "Title of the Event" : "Title of the Event",
     "from" : "from",
     "to" : "to",
-    "All day Event" : "All day Event",
-    "Location" : "Location",
-    "starts" : "starts",
-    "ends" : "ends",
-    "Delete" : "Delete",
-    "Cancel" : "Cancel",
-    "More ..." : "More ...",
-    "Update" : "Update",
-    "Close" : "Close",
-    "Interval" : "Interval",
-    "Description" : "Description",
-    "Export" : "Export",
+    "This event's repeating rule is not supported yet." : "This event's repeating rule is not supported yet.",
+    "Support for advanced rules will be added with subsequent updates." : "Support for advanced rules will be added with subsequent updates.",
+    "Reset repeating rule" : "Reset repeating rule",
+    "Repeat every ..." : "Repeat every ...",
+    "end repeat ..." : "end repeat ...",
+    "times" : "times",
     "Import Calendars" : "Import Calendars",
     "Import canceled" : "Import cancelled",
     "Analyzing calendar" : "Analysing calendar",
