@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendario",
-    "New event" : "Evento nuevo",
-    "Global" : "Global",
-    "None" : "Ninguno",
-    "Attendees" : "Asistentes",
-    "Reminders" : "Recordatorios",
-    "Does not repeat" : "No se repite",
-    "Daily" : "Diariamente",
-    "Weekly" : "Semanalmente",
-    "Every Weekday" : "Todos los días laborables",
-    "Bi-weekly" : "Cada dos semanas",
-    "Monthly" : "Mensualmente",
-    "Yearly" : "Anualmente",
-    "never" : "nunca",
-    "by occurances" : "por acontecimiento",
-    "by date" : "por fecha",
-    "by monthday" : "por día del mes",
-    "by weekday" : "por día de la semana",
-    "by events date" : "por fecha de eventos",
-    "by yearday(s)" : "por día(s) del año",
-    "by week no(s)" : "por numero(s) de semana",
-    "by day and month" : "por día y mes",
-    "Monday" : "Lunes",
-    "Tuesday" : "Martes",
-    "Wednesday" : "Miércoles",
-    "Thursday" : "Jueves",
-    "Friday" : "Viernes",
-    "Saturday" : "Sábado",
-    "Sunday" : "Domingo",
-    "Other" : "Otro",
     "Individual" : "Individual",
     "Group" : "Grupo",
     "Resource" : "Recurso",
@@ -39,9 +10,24 @@ OC.L10N.register(
     "Required" : "Requerido",
     "Optional" : "Opcional",
     "Does not attend" : "No asistir",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Estás en una zona horaria desconocida ({tz}), volviendo a  UTC",
+    "New event" : "Nuevo evento",
+    "Attendees" : "Asistentes",
+    "Reminders" : "Recordatorios",
+    "Repeating" : "Repetición",
     "When shared show full event" : "Mostrar el evento completo al compartir",
     "When shared show only busy" : "Mostrar solamente ocupado al compartir",
     "When shared hide this event" : "Ocultar este evento al compartir",
+    "Please add a title!" : "¡Por favor añade un título!",
+    "Please select a calendar!" : "¡Por favor selecciona un calendario!",
+    "Global" : "Global",
+    "None" : "Ninguno",
+    "Every day" : "Cada día",
+    "Every week" : "Cada semana",
+    "Every month" : "Cada mes",
+    "Every year" : "Cada año",
+    "never" : "nunca",
+    "after" : "después de",
     "At time of event" : "A la hora del evento",
     "5 minutes before" : "5 minutos antes",
     "10 minutes before" : "10 minutos antes",
@@ -58,10 +44,10 @@ OC.L10N.register(
     "hours" : "horas",
     "days" : "días",
     "week" : "semana",
-    "Before" : "Antes",
-    "After" : "Después",
-    "Start" : "Iniciar",
-    "End" : "Fin",
+    "before" : "antes",
+    "start" : "comienzo",
+    "end" : "fin",
+    "Editing reminders of uknown type not supported." : "Los recordatorios de edición de tipo desconocido no están soportados.",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Successfully imported" : "Importado exitosamente",
     "Partially imported, 1 failure" : "Parcialmente importardo, 1 error",
@@ -77,14 +63,30 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} al final del evento",
     "{type} at {time}" : "{type} a {time}",
     "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
+    "Title of the Event" : "Título del evento",
+    "starts" : "comienza",
+    "ends" : "finaliza",
+    "All day Event" : "Todo el día",
+    "Location" : "Ubicación",
+    "Delete" : "Eliminar",
+    "Cancel" : "Cancelar",
+    "More ..." : "Más...",
+    "Create" : "Crear",
+    "Update" : "Actualizar",
+    "Close" : "Cerrar",
+    "Description" : "Descripción",
+    "Export" : "Exportar",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor contacta con el administrador y proponle que desactive la opción \"asset-pipeline.enabled'.",
     "Day" : "Día",
     "Week" : "Semana",
     "Month" : "Mes",
     "Today" : "Hoy",
     "Share Calendar" : "Compartir calendario",
+    "More" : "Más",
+    "Edit" : "Editar",
+    "CalDAV" : "CalDAV",
     "group" : "grupo",
     "New Calendar" : "Nuevo calendario",
-    "Create" : "Crear",
     "Subscriptions" : "Suscripciones",
     "New Subscription" : "Nueva suscripción",
     "Url" : "Url",
@@ -95,26 +97,19 @@ OC.L10N.register(
     "Type" : "Tipo",
     "Relative" : "Relativo",
     "Absolute" : "Absoluto",
-    "Date" : "Fecha",
     "Repeat" : "Repetir",
     "times every" : "veces cada",
     "Add" : "Añadir",
+    "E-Mail address of attendee" : "Correo electrónico del asistente",
     "Please add your email address in the personal settings in order to add attendees." : "Por favor indique su e-mail en los ajustes de su cuenta para agregar asistentes",
-    "Title of the Event" : "Título del evento",
     "from" : "desde",
     "to" : "para",
-    "All day Event" : "Todo el día",
-    "Location" : "Ubicación",
-    "starts" : "comienza",
-    "ends" : "finaliza",
-    "Delete" : "Eliminar",
-    "Cancel" : "Cancelar",
-    "More ..." : "Más...",
-    "Update" : "Actualizar",
-    "Close" : "Cerrar",
-    "Interval" : "Intervalo",
-    "Description" : "Descripción",
-    "Export" : "Exportar",
+    "This event's repeating rule is not supported yet." : "Esta regla de repetición de eventos aún no está soportada.",
+    "Support for advanced rules will be added with subsequent updates." : "El soporte para reglas avanzadas se añadirá en próximas actualizaciones. ",
+    "Reset repeating rule" : "Reinicializar regla de repetición",
+    "Repeat every ..." : "Repetir cada...",
+    "end repeat ..." : "finalizar Repetir ...",
+    "times" : "veces",
     "Import Calendars" : "Importar calendario",
     "Import canceled" : "Importación cancelada",
     "Analyzing calendar" : "Analizando calendario",
