@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Agenda",
-    "New event" : "Nouvel événement",
-    "Global" : "Global",
-    "None" : "Aucun",
-    "Attendees" : "Participants",
-    "Reminders" : "Rappels",
-    "Does not repeat" : "Pas de répétition",
-    "Daily" : "Quotidien",
-    "Weekly" : "Hebdomadaire",
-    "Every Weekday" : "En semaine",
-    "Bi-weekly" : "Bihebdomadaire",
-    "Monthly" : "Mensuel",
-    "Yearly" : "Annuel",
-    "never" : "jamais",
-    "by occurances" : "par occurrences",
-    "by date" : "par date",
-    "by monthday" : "par jour du mois",
-    "by weekday" : "par jour de la semaine",
-    "by events date" : "par date d’événement",
-    "by yearday(s)" : "par jour(s) de l'année",
-    "by week no(s)" : "par numéro(s) de semaine(s)",
-    "by day and month" : "par jour et mois",
-    "Monday" : "Lundi",
-    "Tuesday" : "Mardi",
-    "Wednesday" : "Mercredi",
-    "Thursday" : "Jeudi",
-    "Friday" : "Vendredi",
-    "Saturday" : "Samedi",
-    "Sunday" : "Dimanche",
-    "Other" : "Autre",
     "Individual" : "Individuel",
     "Group" : "Groupe",
     "Resource" : "Ressource",
@@ -39,9 +10,24 @@ OC.L10N.register(
     "Required" : "Requis",
     "Optional" : "Optionnel",
     "Does not attend" : "Ne participera pas",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Vous êtes dans un fuseau horaire inconnu ({tz}), retour à UTC",
+    "New event" : "Nouvel événement",
+    "Attendees" : "Participants",
+    "Reminders" : "Rappels",
+    "Repeating" : "Occurrences",
     "When shared show full event" : "Afficher l'événement complet en cas de partage",
     "When shared show only busy" : "Afficher seulement la plage horaire occupée en cas de partage",
     "When shared hide this event" : "Masquer cet événement en cas de partage",
+    "Please add a title!" : "Veuillez ajouter un titre !",
+    "Please select a calendar!" : "Veuillez sélectionner un calendrier !",
+    "Global" : "Global",
+    "None" : "Aucun",
+    "Every day" : "Chaque jour",
+    "Every week" : "Chaque semaine",
+    "Every month" : "Chaque mois",
+    "Every year" : "Chaque année",
+    "never" : "jamais",
+    "after" : "Après ",
     "At time of event" : "À l'heure de l'événement",
     "5 minutes before" : "5 minutes avant",
     "10 minutes before" : "10 minutes avant",
@@ -58,10 +44,8 @@ OC.L10N.register(
     "hours" : "heures",
     "days" : "jours",
     "week" : "semaine",
-    "Before" : "Avant",
-    "After" : "Après",
-    "Start" : "Début",
-    "End" : "Fin",
+    "before" : "avant",
+    "Editing reminders of uknown type not supported." : "L'édition de rappels de type inconnu n'est pas supportée.",
     "Week {number} of {year}" : "Semaine {number} de {year}",
     "Successfully imported" : "Importé avec succès",
     "Partially imported, 1 failure" : "Partiellement importé, 1 échec",
@@ -77,14 +61,30 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} à la fin de l'événement",
     "{type} at {time}" : "{type} à {time}",
     "{calendar} shared by {owner}" : "{calendar} partagé par {owner}",
+    "Title of the Event" : "Titre de l'événement",
+    "starts" : "démarre",
+    "ends" : "termine",
+    "All day Event" : "Journée entière",
+    "Location" : "Emplacement",
+    "Delete" : "Supprimer",
+    "Cancel" : "Annuler",
+    "More ..." : "Plus…",
+    "Create" : "Créer",
+    "Update" : "Mettre à jour",
+    "Close" : "Fermer",
+    "Description" : "Description",
+    "Export" : "Exporter",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Veuillez contacter votre administrateur afin de lui demander de désactiver l'option de configuration \"asset-pipeline.enabled\".",
     "Day" : "Jour",
     "Week" : "Semaine",
     "Month" : "Mois",
     "Today" : "Aujourd'hui",
     "Share Calendar" : "Partager l'agenda",
+    "More" : "Plus",
+    "Edit" : "Éditer",
+    "CalDAV" : "CalDAV",
     "group" : "groupe",
     "New Calendar" : "Nouvel agenda",
-    "Create" : "Créer",
     "Subscriptions" : "Abonnements",
     "New Subscription" : "Nouvel abonnement",
     "Url" : "URL",
@@ -95,26 +95,19 @@ OC.L10N.register(
     "Type" : "Type",
     "Relative" : "Relatif",
     "Absolute" : "Absolu",
-    "Date" : "Date",
     "Repeat" : "Répéter",
     "times every" : "Répéter tous les",
     "Add" : "Ajouter",
+    "E-Mail address of attendee" : "Adresse courriel du participant",
     "Please add your email address in the personal settings in order to add attendees." : "Veuillez ajouter votre adresse mail dans les paramètres du comptes  dans l'ordre pour ajouter des participants .",
-    "Title of the Event" : "Titre de l'événement",
     "from" : "du",
     "to" : "à",
-    "All day Event" : "Journée entière",
-    "Location" : "Emplacement",
-    "starts" : "démarre",
-    "ends" : "termine",
-    "Delete" : "Supprimer",
-    "Cancel" : "Annuler",
-    "More ..." : "Plus…",
-    "Update" : "Mettre à jour",
-    "Close" : "Fermer",
-    "Interval" : "Intervalle",
-    "Description" : "Description",
-    "Export" : "Exporter",
+    "This event's repeating rule is not supported yet." : "La répétition de cet évènement n'est pas prise en charge pour le moment.",
+    "Support for advanced rules will be added with subsequent updates." : "Le support de règles multiples sera ajouté dans des mises à jour ultérieures.",
+    "Reset repeating rule" : "Réinitialiser la règle de répétition",
+    "Repeat every ..." : "Répéter tous les ...",
+    "end repeat ..." : "Arrêter la répétition ...",
+    "times" : "fois",
     "Import Calendars" : "Importer des agendas",
     "Import canceled" : "Importation annulée",
     "Analyzing calendar" : "Analyse de l'agenda en cours",
