@@ -2,33 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Naptár",
-    "New event" : "Új esemény",
-    "None" : "Egyik sem",
-    "Attendees" : "Résztvevők",
-    "Does not repeat" : "Nem ismétlődik",
-    "Daily" : "naponta",
-    "Weekly" : "hetente",
-    "Every Weekday" : "minden hétköznap",
-    "Bi-weekly" : "kéthetente",
-    "Monthly" : "havonta",
-    "Yearly" : "évente",
-    "never" : "soha",
-    "by occurances" : "előfordulások száma szerint",
-    "by date" : "dátum szerint",
-    "by monthday" : "hónap napja szerint",
-    "by weekday" : "hét napja szerint",
-    "by events date" : "az esemény napja szerint",
-    "by yearday(s)" : "az év napja(i) szerint",
-    "by week no(s)" : "hét sorszáma szerint",
-    "by day and month" : "nap és hónap szerint",
-    "Monday" : "hétfő",
-    "Tuesday" : "kedd",
-    "Wednesday" : "szerda",
-    "Thursday" : "csütörtök",
-    "Friday" : "péntek",
-    "Saturday" : "szombat",
-    "Sunday" : "vasárnap",
-    "Other" : "más",
     "Individual" : "egyéni",
     "Group" : "Csoport",
     "Resource" : "Forrás",
@@ -36,6 +9,22 @@ OC.L10N.register(
     "Unknown" : "Ismeretlen",
     "Required" : "Szükséges",
     "Optional" : "Opcionális",
+    "Does not attend" : "Nem vesz részt",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ismeretlen időzónában tartózkodik ({tz}), visszaállítás UTC-re",
+    "New event" : "Új esemény",
+    "Attendees" : "Résztvevők",
+    "Reminders" : "Emlékeztetők",
+    "Repeating" : "Ismétlődő",
+    "Please add a title!" : "Kérjük töltse ki a címet!",
+    "Please select a calendar!" : "Kérjük válasszon egy naptárat!",
+    "Global" : "Globális",
+    "None" : "Egyik sem",
+    "Every day" : "minden nap",
+    "Every week" : "minden hét",
+    "Every month" : "minden hónap",
+    "Every year" : "minden év",
+    "never" : "soha",
+    "after" : "után",
     "At time of event" : "az eseménnyel egy időben",
     "5 minutes before" : "5 perccel előtte",
     "10 minutes before" : "10 perccel előtte",
@@ -52,21 +41,41 @@ OC.L10N.register(
     "hours" : "óra",
     "days" : "nap",
     "week" : "hét",
-    "Before" : "előtte",
-    "After" : "utána",
-    "Start" : "Kezdés",
-    "End" : "Vége",
+    "before" : "előtte",
+    "start" : "kezdet",
+    "end" : "vég",
+    "Week {number} of {year}" : "{year} év {number}. hete",
+    "Successfully imported" : "Sikeresen importálva!",
+    "Partially imported, 1 failure" : "Részben importálva, 1 hiba",
+    "Partially imported, {n} failures" : "Részben importálva, {n} hiba",
     "Audio alarm" : "Hangriasztás",
     "Pop-up" : "Felugró ablak",
     "E-Mail" : "E-mail",
+    "{type} at {time}" : "{type} ekkor: {time}",
+    "{calendar} shared by {owner}" : "{calendar} megosztója: {owner}",
+    "Title of the Event" : "Az esemény címe",
+    "starts" : "kezdete",
+    "ends" : "vége",
+    "All day Event" : "Mindennapos esemény",
+    "Location" : "Hely",
+    "Delete" : "Törlés",
+    "Cancel" : "Mégsem",
+    "More ..." : "Bővebben...",
+    "Create" : "Létrehozás",
+    "Update" : "Frissítés",
+    "Close" : "Bezárás",
+    "Description" : "Leírás",
+    "Export" : "Exportálás",
     "Day" : "Nap",
     "Week" : "Hét",
     "Month" : "Hónap",
     "Today" : "Ma",
     "Share Calendar" : "A naptár megosztása",
+    "More" : "Több",
+    "Edit" : "Szerkesztés",
+    "CalDAV" : "CalDAV",
     "group" : "csoport",
     "New Calendar" : "Új naptár",
-    "Create" : "Létrehozás",
     "Subscriptions" : "Feliratkozások",
     "New Subscription" : "Új feliratkozás",
     "Url" : "Hivatkozás",
@@ -77,23 +86,15 @@ OC.L10N.register(
     "Type" : "Típus",
     "Relative" : "Relatív",
     "Absolute" : "Abszolút",
-    "Date" : "Dátum",
     "Repeat" : "Ismétlés",
     "Add" : "Hozzáadás",
-    "Title of the Event" : "Az esemény címe",
     "from" : "feladó",
     "to" : "címzett",
-    "All day Event" : "Mindennapos esemény",
-    "Location" : "Hely",
-    "Delete" : "Törlés",
-    "Cancel" : "Mégsem",
-    "More ..." : "Bővebben...",
-    "Update" : "Frissítés",
-    "Close" : "Bezárás",
-    "Interval" : "Időköz",
-    "Description" : "Leírás",
-    "Export" : "Exportálás",
+    "Repeat every ..." : "Ismétlődjön minden ...",
+    "end repeat ..." : "ismétlődés vége ...",
+    "times" : "alkalommal",
     "Import Calendars" : "Naptár importálása",
+    "Import canceled" : "Importálás megszakítva.",
     "Analyzing calendar" : "Naptár analizálása",
     "New calendar" : "Új naptár",
     "Import scheduled" : "Importálás beütemezve",
