@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendario",
-    "New event" : "Nuovo evento",
-    "Global" : "Globale",
-    "None" : "Nessuno",
-    "Attendees" : "Partecipanti",
-    "Reminders" : "Promemoria",
-    "Does not repeat" : "Non ripetere",
-    "Daily" : "Quotidiano",
-    "Weekly" : "Settimanale",
-    "Every Weekday" : "Ogni giorno della settimana",
-    "Bi-weekly" : "Ogni due settimane",
-    "Monthly" : "Mensile",
-    "Yearly" : "Annuale",
-    "never" : "mai",
-    "by occurances" : "Per occorrenze",
-    "by date" : "per data",
-    "by monthday" : "per giorno del mese",
-    "by weekday" : "per giorno della settimana",
-    "by events date" : "per data evento",
-    "by yearday(s)" : "per giorno/i dell'anno",
-    "by week no(s)" : "per numero della settimana",
-    "by day and month" : "per giorno e mese",
-    "Monday" : "Lunedì",
-    "Tuesday" : "Martedì",
-    "Wednesday" : "Mercoledì",
-    "Thursday" : "Giovedì",
-    "Friday" : "Venerdì",
-    "Saturday" : "Sabato",
-    "Sunday" : "Domenica",
-    "Other" : "Altro",
     "Individual" : "Singolo",
     "Group" : "Gruppo",
     "Resource" : "Risorsa",
@@ -39,9 +10,24 @@ OC.L10N.register(
     "Required" : "Richiesto",
     "Optional" : "Facoltativo",
     "Does not attend" : "Non partecipa",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Sei in un fuso orario sconosciuto ({tz}), ripiego su UTC",
+    "New event" : "Nuovo evento",
+    "Attendees" : "Partecipanti",
+    "Reminders" : "Promemoria",
+    "Repeating" : "Ripetizione",
     "When shared show full event" : "Se condiviso, mostra l'evento completo",
     "When shared show only busy" : "Se condiviso, mostra solo occupato",
     "When shared hide this event" : "Se condiviso, nascondi questo evento",
+    "Please add a title!" : "Aggiungi un titolo!",
+    "Please select a calendar!" : "Seleziona un calendario!",
+    "Global" : "Globale",
+    "None" : "Nessuno",
+    "Every day" : "Ogni giorno",
+    "Every week" : "Ogni settimana",
+    "Every month" : "Ogni mese",
+    "Every year" : "Ogni anno",
+    "never" : "mai",
+    "after" : "dopo",
     "At time of event" : "Al momento dell'evento",
     "5 minutes before" : "5 minuti prima",
     "10 minutes before" : "10 minuti prima",
@@ -58,10 +44,10 @@ OC.L10N.register(
     "hours" : "ore",
     "days" : "giorni",
     "week" : "settimana",
-    "Before" : "Prima",
-    "After" : "Dopo",
-    "Start" : "Avvia",
-    "End" : "Fine",
+    "before" : "prima",
+    "start" : "inizia",
+    "end" : "finisce",
+    "Editing reminders of uknown type not supported." : "La modifica dei promemoria di tipo sconosciuto non è supportata.",
     "Week {number} of {year}" : "Settimana {number} del {year}",
     "Successfully imported" : "Importato correttamente",
     "Partially imported, 1 failure" : "Importato parzialmente, 1 problema",
@@ -77,14 +63,31 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} alla fine dell'evento",
     "{type} at {time}" : "{type} alle {time}",
     "{calendar} shared by {owner}" : "{calendar} condiviso da {owner}",
+    "Title of the Event" : "Titolo dell'evento",
+    "starts" : "inizia",
+    "ends" : "finisce",
+    "All day Event" : "Evento di un giorno intero",
+    "Location" : "Posizione",
+    "Delete" : "Elimina",
+    "Cancel" : "Annulla",
+    "More ..." : "Altro...",
+    "Create" : "Crea",
+    "Update" : "Aggiorna",
+    "Close" : "Chiudi",
+    "Description" : "Descrizione",
+    "Export" : "Esporta",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa di un bug a monte, il calendario non è attualmente in grado di fornire supporto per la funzionalità di asset pipeline.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contatta il tuo amministratore e chiedigli di disabilitare l'opzione di configurazione \"asset-pipeline.enabled\".",
     "Day" : "Giorno",
     "Week" : "Settimana",
     "Month" : "Mese",
     "Today" : "Oggi",
     "Share Calendar" : "Condividi calendario",
+    "More" : "Altro",
+    "Edit" : "Modifica",
+    "CalDAV" : "CalDAV",
     "group" : "gruppo",
     "New Calendar" : "Nuovo calendario",
-    "Create" : "Crea",
     "Subscriptions" : "Sottoscrizioni",
     "New Subscription" : "Nuova sottoscrizione",
     "Url" : "URL",
@@ -95,27 +98,19 @@ OC.L10N.register(
     "Type" : "Tipo",
     "Relative" : "Relativo",
     "Absolute" : "Assoluto",
-    "Date" : "Data",
     "Repeat" : "Ripeti",
     "times every" : "volte ogni",
     "Add" : "Aggiungi",
     "E-Mail address of attendee" : "Indirizzo email del partecipante",
     "Please add your email address in the personal settings in order to add attendees." : "Aggiungi il tuo indirizzo email nelle impostazioni personali per aggiungere i partecipanti.",
-    "Title of the Event" : "Titolo dell'evento",
     "from" : "da",
     "to" : "a",
-    "All day Event" : "Evento di un giorno intero",
-    "Location" : "Posizione",
-    "starts" : "inizia",
-    "ends" : "finisce",
-    "Delete" : "Elimina",
-    "Cancel" : "Annulla",
-    "More ..." : "Altro...",
-    "Update" : "Aggiorna",
-    "Close" : "Chiudi",
-    "Interval" : "Intervallo",
-    "Description" : "Descrizione",
-    "Export" : "Esporta",
+    "This event's repeating rule is not supported yet." : "Questa regola di ripetizione dell'evento non è ancora supportata.",
+    "Support for advanced rules will be added with subsequent updates." : "Il supporto per le regole avanzate sarà aggiunto con aggiornamenti successivi.",
+    "Reset repeating rule" : "Ripristina la regola di ripetizione",
+    "Repeat every ..." : "Ripeti ogni...",
+    "end repeat ..." : "fine della ripetizione...",
+    "times" : "volte",
     "Import Calendars" : "Importa calendari",
     "Import canceled" : "Importazione annullata",
     "Analyzing calendar" : "Analisi del calendario",
