@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "カレンダー",
-    "New event" : "新しいイベント",
-    "Global" : "全般",
-    "None" : "なし",
-    "Attendees" : "参加者",
-    "Reminders" : "リマインダー",
-    "Does not repeat" : "繰り返さない",
-    "Daily" : "毎日",
-    "Weekly" : "毎週",
-    "Every Weekday" : "平日は毎日",
-    "Bi-weekly" : "2週間ごと",
-    "Monthly" : "毎月",
-    "Yearly" : "毎年",
-    "never" : "なし",
-    "by occurances" : "回数で指定",
-    "by date" : "日付で指定",
-    "by monthday" : "日にちで指定",
-    "by weekday" : "曜日で指定",
-    "by events date" : "日付で指定",
-    "by yearday(s)" : "日番号で指定",
-    "by week no(s)" : "週番号で指定",
-    "by day and month" : "月と日で指定",
-    "Monday" : "月",
-    "Tuesday" : "火",
-    "Wednesday" : "水",
-    "Thursday" : "木",
-    "Friday" : "金",
-    "Saturday" : "土",
-    "Sunday" : "日",
-    "Other" : "その他",
     "Individual" : "個人",
     "Group" : "グループ",
     "Resource" : "リソース",
@@ -39,9 +10,22 @@ OC.L10N.register(
     "Required" : "必須",
     "Optional" : "オプション",
     "Does not attend" : "出席しない",
+    "New event" : "新しいイベント",
+    "Attendees" : "参加者",
+    "Reminders" : "リマインダー",
+    "Repeating" : "繰り返し",
     "When shared show full event" : "共有時にすべてのイベントを表示",
     "When shared show only busy" : "共有時に実行中のみを表示",
     "When shared hide this event" : "共有時にこのイベントを隠す",
+    "Please add a title!" : "タイトルを追加してください！",
+    "Please select a calendar!" : "カレンダーを選択してください！",
+    "Global" : "全般",
+    "None" : "なし",
+    "Every day" : "毎日",
+    "Every week" : "毎週",
+    "Every month" : "毎月",
+    "Every year" : "毎年",
+    "never" : "なし",
     "At time of event" : "イベント時",
     "5 minutes before" : "5分前",
     "10 minutes before" : "10分前",
@@ -58,10 +42,6 @@ OC.L10N.register(
     "hours" : "時間",
     "days" : "日",
     "week" : "週",
-    "Before" : "前",
-    "After" : "後",
-    "Start" : "開始",
-    "End" : "終了",
     "Week {number} of {year}" : "{year}の{number} 週",
     "Successfully imported" : "インポートに成功しました",
     "Partially imported, 1 failure" : "不完全なインポート，失敗1",
@@ -77,14 +57,28 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} イベント終了時",
     "{type} at {time}" : "{type} {time} 時",
     "{calendar} shared by {owner}" : "{owner} が共有中の{calendar} ",
+    "Title of the Event" : "イベントのタイトル",
+    "starts" : "開始",
+    "ends" : "終了",
+    "All day Event" : "終日イベント",
+    "Location" : "場所",
+    "Delete" : "削除",
+    "Cancel" : "キャンセル",
+    "More ..." : "さらに表示 ...",
+    "Create" : "作成",
+    "Update" : "アップデート",
+    "Close" : "閉じる",
+    "Description" : "説明",
+    "Export" : "エクスポート",
     "Day" : "日",
     "Week" : "週",
     "Month" : "月",
     "Today" : "今日",
     "Share Calendar" : "カレンダーを共有する",
+    "More" : "もっと見る",
+    "Edit" : "編集",
     "group" : "グループ",
     "New Calendar" : "新しいカレンダーを作成",
-    "Create" : "作成",
     "Subscriptions" : "購読",
     "New Subscription" : "新しい購読",
     "Url" : "Url",
@@ -95,26 +89,12 @@ OC.L10N.register(
     "Type" : "種類",
     "Relative" : "相対指定",
     "Absolute" : "絶対指定",
-    "Date" : "日付",
     "Repeat" : "繰り返し",
     "times every" : "繰り返し",
     "Add" : "追加",
     "Please add your email address in the personal settings in order to add attendees." : "出席者に追加するにはアカウント設定でメールアドレスを追加してください",
-    "Title of the Event" : "イベントのタイトル",
     "from" : "差出人",
     "to" : "宛先",
-    "All day Event" : "終日イベント",
-    "Location" : "場所",
-    "starts" : "開始",
-    "ends" : "終了",
-    "Delete" : "削除",
-    "Cancel" : "キャンセル",
-    "More ..." : "さらに表示 ...",
-    "Update" : "アップデート",
-    "Close" : "閉じる",
-    "Interval" : "間隔",
-    "Description" : "説明",
-    "Export" : "エクスポート",
     "Import Calendars" : "カレンダーのインポート",
     "Import canceled" : "インポートはキャンセルされました",
     "Analyzing calendar" : "カレンダーの解析中",
