@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "달력",
-    "New event" : "새 일정",
-    "Global" : "전역",
-    "None" : "없음",
-    "Attendees" : "참석자",
-    "Reminders" : "알림",
-    "Does not repeat" : "반복 없음",
-    "Daily" : "매일",
-    "Weekly" : "매주",
-    "Every Weekday" : "매주 특정 요일",
-    "Bi-weekly" : "2주",
-    "Monthly" : "매월",
-    "Yearly" : "매년",
-    "never" : "없음",
-    "by occurances" : "지정한 횟수까지",
-    "by date" : "지정한 날짜까지",
-    "by monthday" : "지정한 달까지",
-    "by weekday" : "지정한 요일까지",
-    "by events date" : "일정 날짜 순",
-    "by yearday(s)" : "날짜 번호 순",
-    "by week no(s)" : "주 번호 순",
-    "by day and month" : "날짜 순",
-    "Monday" : "월요일",
-    "Tuesday" : "화요일",
-    "Wednesday" : "수요일",
-    "Thursday" : "목요일",
-    "Friday" : "금요일",
-    "Saturday" : "토요일",
-    "Sunday" : "일요일",
-    "Other" : "기타",
     "Individual" : "개별",
     "Group" : "그룹",
     "Resource" : "자원",
@@ -39,9 +10,16 @@ OC.L10N.register(
     "Required" : "필요함",
     "Optional" : "선택적",
     "Does not attend" : "참석하지 않음",
+    "New event" : "새 일정",
+    "Attendees" : "참석자",
+    "Reminders" : "알림",
+    "Repeating" : "반복",
     "When shared show full event" : "전체 일정 공유",
     "When shared show only busy" : "바쁨/한가함만 공유",
     "When shared hide this event" : "일정 공유하지 않음",
+    "Global" : "전역",
+    "None" : "없음",
+    "never" : "없음",
     "At time of event" : "일정 정각",
     "5 minutes before" : "5분 전",
     "10 minutes before" : "10분 전",
@@ -58,10 +36,6 @@ OC.L10N.register(
     "hours" : "시간",
     "days" : "일",
     "week" : "주",
-    "Before" : "이전",
-    "After" : "이후",
-    "Start" : "시작",
-    "End" : "끝",
     "Week {number} of {year}" : "{year}년 제 {number}주",
     "Successfully imported" : "성공적으로 가져옴",
     "Partially imported, 1 failure" : "일부만 가져옴, 1개 항목 실패",
@@ -77,14 +51,28 @@ OC.L10N.register(
     "{type} at the event's end" : "일정 종료 시 {type}",
     "{type} at {time}" : "{time}에 {type}",
     "{calendar} shared by {owner}" : "{owner} 님이 공유한 달력",
+    "Title of the Event" : "일정 제목",
+    "starts" : "시작",
+    "ends" : "끝",
+    "All day Event" : "종일 일정",
+    "Location" : "위치",
+    "Delete" : "삭제",
+    "Cancel" : "취소",
+    "More ..." : "더 보기...",
+    "Create" : "만들기",
+    "Update" : "업데이트",
+    "Close" : "닫기",
+    "Description" : "설명",
+    "Export" : "내보내기",
     "Day" : "일",
     "Week" : "주",
     "Month" : "달",
     "Today" : "오늘",
     "Share Calendar" : "달력 공유",
+    "More" : "더 보기",
+    "Edit" : "편집",
     "group" : "그룹",
     "New Calendar" : "새 달력",
-    "Create" : "만들기",
     "Subscriptions" : "구독",
     "New Subscription" : "새 구독",
     "Url" : "URL",
@@ -95,25 +83,11 @@ OC.L10N.register(
     "Type" : "종류",
     "Relative" : "상대적",
     "Absolute" : "절대적",
-    "Date" : "날짜",
     "Repeat" : "반복",
     "Add" : "추가",
     "Please add your email address in the personal settings in order to add attendees." : "참석자 목록을 편집하려면 개인 설정에서 이메일 주소를 추가하십시오.",
-    "Title of the Event" : "일정 제목",
     "from" : "시작",
     "to" : "끝",
-    "All day Event" : "종일 일정",
-    "Location" : "위치",
-    "starts" : "시작",
-    "ends" : "끝",
-    "Delete" : "삭제",
-    "Cancel" : "취소",
-    "More ..." : "더 보기...",
-    "Update" : "업데이트",
-    "Close" : "닫기",
-    "Interval" : "간격",
-    "Description" : "설명",
-    "Export" : "내보내기",
     "Import Calendars" : "달력 가져오기",
     "Import canceled" : "가져오기 취소됨",
     "Analyzing calendar" : "달력 분석 중",
