@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
-    "New event" : "Nieuwe afspraak",
-    "Global" : "Globaal",
-    "None" : "Geen",
-    "Attendees" : "Deelnemers",
-    "Reminders" : "Herinneringen",
-    "Does not repeat" : "Geen",
-    "Daily" : "Dagelijks",
-    "Weekly" : "Wekelijks",
-    "Every Weekday" : "Elke weekdag",
-    "Bi-weekly" : "Tweewekelijks",
-    "Monthly" : "Maandelijks",
-    "Yearly" : "Jaarlijks",
-    "never" : "geen",
-    "by occurances" : "volgens afspraken",
-    "by date" : "op datum",
-    "by monthday" : "per dag van de maand",
-    "by weekday" : "op weekdag",
-    "by events date" : "volgens gebeurtenisdatum",
-    "by yearday(s)" : "volgens jaardag(en)",
-    "by week no(s)" : "volgens weeknr(s)",
-    "by day and month" : "per dag en maand",
-    "Monday" : "maandag",
-    "Tuesday" : "dinsdag",
-    "Wednesday" : "woensdag",
-    "Thursday" : "donderdag",
-    "Friday" : "vrijdag",
-    "Saturday" : "zaterdag",
-    "Sunday" : "zondag",
-    "Other" : "Overig",
     "Individual" : "Individueel",
     "Group" : "Groep",
     "Resource" : "Bron",
@@ -39,9 +10,24 @@ OC.L10N.register(
     "Required" : "Vereist",
     "Optional" : "Optioneel",
     "Does not attend" : "Neemt niet deel",
+    "Please create a calendar first." : "Maak eerst een kalender aan",
+    "New event" : "Nieuwe afspraak",
+    "Attendees" : "Deelnemers",
+    "Reminders" : "Herinneringen",
+    "Repeating" : "Herhaling",
     "When shared show full event" : "Wanneer gedeeld toon gehele gebeurtenis",
     "When shared show only busy" : "Wanneer gedeeld toon enkel beschikbaarheid",
     "When shared hide this event" : "Wanneer gedeeld verberg deze gebeurtenis",
+    "Please add a title!" : "Voeg een titel toe!",
+    "Please select a calendar!" : "Selecteer een agenda!",
+    "Global" : "Globaal",
+    "None" : "Geen",
+    "Every day" : "Iedere dag",
+    "Every week" : "Iedere week",
+    "Every month" : "Iedere maand",
+    "Every year" : "Elk jaar",
+    "never" : "geen",
+    "after" : "na",
     "At time of event" : "Op de tijd van de afspraak",
     "5 minutes before" : "5 minuten vooraf",
     "10 minutes before" : "10 minuten vooraf",
@@ -58,10 +44,10 @@ OC.L10N.register(
     "hours" : "uur",
     "days" : "dagen",
     "week" : "week",
-    "Before" : "Voor",
-    "After" : "Na",
-    "Start" : "Start",
-    "End" : "Einde",
+    "before" : "voor",
+    "start" : "start",
+    "end" : "einde",
+    "Editing reminders of uknown type not supported." : "Bijwerken van herinneringen van een onbekend type is niet ondersteund.",
     "Week {number} of {year}" : "Week {number} van {year}",
     "Successfully imported" : "Succesvol geïmporteerd",
     "Partially imported, 1 failure" : "Gedeeltelijk geïmporteerd, 1 fout",
@@ -77,14 +63,31 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} bij het eind van de afspraak",
     "{type} at {time}" : "{type} om {time}",
     "{calendar} shared by {owner}" : "{calendar} gedeeld door {owner}",
+    "Title of the Event" : "Titel van de afspraak",
+    "starts" : "begint",
+    "ends" : "eindigt",
+    "All day Event" : "Hele dag",
+    "Location" : "Locatie",
+    "Delete" : "Verwijderen",
+    "Cancel" : "Annuleren",
+    "More ..." : "Meer...",
+    "Create" : "Aanmaken",
+    "Update" : "Bijwerken",
+    "Close" : "Sluiten",
+    "Description" : "Beschrijving",
+    "Export" : "Exporteer",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Wegens een upstream bug kan de kalender nu de asset pipeline mogelijkheid niet ondersteunen.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Neem contact op met de beheerder en vraag om de configuratieoptie \"asset-pipeline.enabled\" uit te schakelen.",
     "Day" : "Dag",
     "Week" : "Week",
     "Month" : "Maand",
     "Today" : "Vandaag",
     "Share Calendar" : "Delen agenda",
+    "More" : "Meer",
+    "Edit" : "Bewerk",
+    "CalDAV" : "CalDAV",
     "group" : "groep",
     "New Calendar" : "Nieuwe agenda",
-    "Create" : "Aanmaken",
     "Subscriptions" : "Abonnementen",
     "New Subscription" : "Nieuw abonnement",
     "Url" : "Url",
@@ -95,26 +98,19 @@ OC.L10N.register(
     "Type" : "Type",
     "Relative" : "Relatief",
     "Absolute" : "Absoluut",
-    "Date" : "Datum",
     "Repeat" : "Herhaling",
     "times every" : "keer elke",
     "Add" : "Toevoegen",
+    "E-Mail address of attendee" : "E-mailadres van deelnemer",
     "Please add your email address in the personal settings in order to add attendees." : "Stel uw email adres in in de account instellingen om aanwezigen toe te voegen.",
-    "Title of the Event" : "Titel van de afspraak",
     "from" : "van",
     "to" : "naar",
-    "All day Event" : "Hele dag",
-    "Location" : "Locatie",
-    "starts" : "begint",
-    "ends" : "eindigt",
-    "Delete" : "Verwijderen",
-    "Cancel" : "Annuleren",
-    "More ..." : "Meer...",
-    "Update" : "Bijwerken",
-    "Close" : "Sluiten",
-    "Interval" : "Interval",
-    "Description" : "Beschrijving",
-    "Export" : "Exporteer",
+    "This event's repeating rule is not supported yet." : "De herhaalregel van deze afspraak wordt nog niet ondersteund.",
+    "Support for advanced rules will be added with subsequent updates." : "Ondersteuning voor geavanceerde regels wordt in toekomstige releases toegevoegd.",
+    "Reset repeating rule" : "Herstel de herhaalregel",
+    "Repeat every ..." : "Herhaal iedere ...",
+    "end repeat ..." : "eind herhalen ...",
+    "times" : "keer",
     "Import Calendars" : "Importeer agenda's",
     "Import canceled" : "Importeren geannuleerd",
     "Analyzing calendar" : "Analyseren agenda",
