@@ -2,39 +2,32 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendarz",
-    "New event" : "Nowe zdarzenie",
-    "None" : "Nic",
-    "Attendees" : "Uczestnicy",
-    "Reminders" : "Przypomnienia",
-    "Does not repeat" : "Nie powtarza się",
-    "Daily" : "Codziennie",
-    "Weekly" : "Cotygodniowo",
-    "Every Weekday" : "Każdego dnia tygodnia",
-    "Bi-weekly" : "Co drugi tydzień",
-    "Monthly" : "Comiesięcznie",
-    "Yearly" : "Corocznie",
-    "never" : "nigdy",
-    "by occurances" : "po wystąpieniach",
-    "by date" : "po dacie",
-    "by monthday" : "po dniu miesiąca",
-    "by weekday" : "po dniu tygodnia",
-    "by events date" : "po datach wydarzeń",
-    "by yearday(s)" : "po dniach roku",
-    "by week no(s)" : "po tygodniach",
-    "by day and month" : "po dniu i miesiącu",
-    "Monday" : "Poniedziałek",
-    "Tuesday" : "Wtorek",
-    "Wednesday" : "Środa",
-    "Thursday" : "Czwartek",
-    "Friday" : "Piątek",
-    "Saturday" : "Sobota",
-    "Sunday" : "Niedziela",
-    "Other" : "Inne",
+    "Individual" : "Indywidualny",
     "Group" : "Grupa",
+    "Resource" : "Źródło",
     "Room" : "Pokój",
     "Unknown" : "Nieznany",
     "Required" : "Wymagany",
     "Optional" : "Opcjonalny",
+    "Does not attend" : "Nie uczestniczy",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jesteś w nieznanej strefie czasowej ({tz}), powracanie do UTC",
+    "Please create a calendar first." : "Proszę najpierw stworzyć kalendarz.",
+    "New event" : "Nowe zdarzenie",
+    "Attendees" : "Uczestnicy",
+    "Reminders" : "Przypomnienia",
+    "Repeating" : "Powtarzające się",
+    "When shared show full event" : "Kiedy współdzieli pokaż całe wydarzenie",
+    "When shared show only busy" : "Kiedy współdzieli pokaż tylko zajęty",
+    "When shared hide this event" : "Kiedy współdzieli ukryj to wydarzenie",
+    "Please add a title!" : "Proszę dodać tytuł!",
+    "Please select a calendar!" : "Proszę wybrać kalendarz!",
+    "None" : "Brak.",
+    "Every day" : "Codziennie",
+    "Every week" : "Co tydzień",
+    "Every month" : "Co miesiąc",
+    "Every year" : "Co roku",
+    "never" : "nigdy",
+    "after" : "po",
     "At time of event" : "W momencie zdarzenia",
     "5 minutes before" : "5 minut przed",
     "10 minutes before" : "10 minut przed",
@@ -50,10 +43,9 @@ OC.L10N.register(
     "hours" : "godzin",
     "days" : "dniach",
     "week" : "tydzień",
-    "Before" : "Przed",
-    "After" : "Po",
-    "Start" : "Start",
-    "End" : "Koniec",
+    "before" : "przed",
+    "start" : "rozpocznij",
+    "end" : "zakończ",
     "Week {number} of {year}" : "{number}. tydzień {year}",
     "Successfully imported" : "Import zakończył się pomyślnie",
     "Partially imported, 1 failure" : "Import wykonany częściowo, 1 błąd",
@@ -65,15 +57,33 @@ OC.L10N.register(
     "{type} {time} before the event ends" : "{type} {time} przed zakończeniem zdarzenia",
     "{type} {time} after the event starts" : "{type} {time} po rozpoczęciu zdarzenia",
     "{type} {time} after the event ends" : "{type} {time} po zakończeniu zdarzenia",
+    "{type} at the event's start" : "{type} na początku wydarzenia",
+    "{type} at the event's end" : "{type} na końcu wydarzenia",
+    "{type} at {time}" : "{type} o {time}",
     "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
+    "Title of the Event" : "Nazwa wydarzenia",
+    "starts" : "rozpoczyna się",
+    "ends" : "kończy się",
+    "All day Event" : "Wydarzenie całodniowe",
+    "Location" : "Lokalizacja",
+    "Delete" : "Usuń",
+    "Cancel" : "Anuluj",
+    "More ..." : "Więcej...",
+    "Create" : "Utwórz",
+    "Update" : "Aktualizuj",
+    "Close" : "Zamknij",
+    "Description" : "Opis",
+    "Export" : "Eksportuj",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Skontaktuj się z administratorem i poproś o wyłączenie opcji \"asset-pipeline.enabled\"  w konfiguracji.",
     "Day" : "Dzień",
     "Week" : "Tydzień",
     "Month" : "Miesiąc",
     "Today" : "Dziś",
     "Share Calendar" : "Współdziel kalendarz",
+    "More" : "Więcej",
+    "Edit" : "Edytuj",
     "group" : "grupa",
     "New Calendar" : "Nowy kalendarz",
-    "Create" : "Utwórz",
     "Subscriptions" : "Subskrypcje",
     "New Subscription" : "Nowa Subskrypcja",
     "Url" : "Url",
@@ -82,26 +92,19 @@ OC.L10N.register(
     "Save Event" : "Zapisz zdarzenie",
     "Time" : "Czas",
     "Type" : "Typ",
-    "Date" : "Data",
     "Repeat" : "Powtarzaj",
     "Add" : "Dodaj",
+    "E-Mail address of attendee" : "Adres e-mail uczestnika",
     "Please add your email address in the personal settings in order to add attendees." : "Aby móc dodać uczestników, proszę ustawić adres e-mail w ustawieniach konta.",
-    "Title of the Event" : "Nazwa wydarzenia",
     "from" : "z",
     "to" : "do",
-    "All day Event" : "Wydarzenie całodniowe",
-    "Location" : "Lokalizacja",
-    "Delete" : "Usuń",
-    "Cancel" : "Anuluj",
-    "More ..." : "Więcej...",
-    "Update" : "Aktualizuj",
-    "Close" : "Zamknij",
-    "Interval" : "Odstęp",
-    "Description" : "Opis",
-    "Export" : "Eksportuj",
+    "Reset repeating rule" : "Zresetuj powtarzającą się zasadę",
+    "Repeat every ..." : "Powtarzaj każdą...",
+    "end repeat ..." : "zakończ powtarzanie ...",
     "Import Calendars" : "Importuj Kalendarze",
     "Import canceled" : "Import anulowany",
     "Analyzing calendar" : "Analiza kalendarza",
+    "The file contains objects incompatible with the selected calendar" : "Plik zawiera obiekty niekompatybilne z wybranym kalendarzem",
     "New calendar" : "Nowy kalendarz",
     "Import scheduled" : "Import został zaplanowany",
     "Settings" : "Ustawienia",
