@@ -2,46 +2,32 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendário",
-    "New event" : "Novo evento",
-    "Global" : "Global",
-    "None" : "Nenhum",
-    "Attendees" : "Participantes",
-    "Reminders" : "Lembretes",
-    "Does not repeat" : "Não repete",
-    "Daily" : "Diariamente",
-    "Weekly" : "Semanalmente",
-    "Every Weekday" : "Todos os dias da semana",
-    "Bi-weekly" : "Bi-semanal",
-    "Monthly" : "Mensal",
-    "Yearly" : "Anual",
-    "never" : "nunca",
-    "by occurances" : "por ocorrências",
-    "by date" : "por data",
-    "by monthday" : "por dia do mês",
-    "by weekday" : "por dia da semana",
-    "by events date" : "por data de evento",
-    "by yearday(s)" : "por dia(s) do ano",
-    "by week no(s)" : "por semana(s)",
-    "by day and month" : "por dia e mês",
-    "Monday" : "Segunda",
-    "Tuesday" : "Terça-feira",
-    "Wednesday" : "Quarta-feira",
-    "Thursday" : "Quinta-feira",
-    "Friday" : "Sexta-feira",
-    "Saturday" : "Sábado",
-    "Sunday" : "Domingo",
-    "Other" : "Outro",
     "Individual" : "Individual",
     "Group" : "Grupo",
     "Resource" : "Recurso",
     "Room" : "Quarto",
     "Unknown" : "Desconhecido",
-    "Required" : "Necessário",
+    "Required" : "Obrigatório",
     "Optional" : "Opcional",
     "Does not attend" : "Não comparecerá",
-    "When shared show full event" : "Quando partilhado mostrar evento completo",
-    "When shared show only busy" : "Quando partilhado mostrar apenas ocupados",
-    "When shared hide this event" : "Quando partilhado esconder este evento",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Está numa zona horário desconhecida ({tz}), a repor para UTC",
+    "New event" : "Novo evento",
+    "Attendees" : "Participantes",
+    "Reminders" : "Lembretes",
+    "Repeating" : "Repetição",
+    "When shared show full event" : "Quando partilhado, mostrar evento completo",
+    "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
+    "When shared hide this event" : "Quando partilhado, ocultar este evento",
+    "Please add a title!" : "Por favor, adicione um titulo!",
+    "Please select a calendar!" : "Por favor, selecione um calendário!",
+    "Global" : "Global",
+    "None" : "Nenhum",
+    "Every day" : "Diariamente",
+    "Every week" : "Semanalmente",
+    "Every month" : "Mensalmente",
+    "Every year" : "Anualmente",
+    "never" : "nunca",
+    "after" : "depois",
     "At time of event" : "À hora do evento",
     "5 minutes before" : "5 minutos antes",
     "10 minutes before" : "10 minutos antes",
@@ -50,24 +36,24 @@ OC.L10N.register(
     "1 hour before" : "1 hora antes",
     "2 hours before" : "2 horas antes",
     "Custom" : "Personalizado",
-    "Audio" : "Audio",
+    "Audio" : "Áudio",
     "E Mail" : "E-mail",
-    "Pop up" : "Aparecer",
-    "sec" : "seg",
+    "Pop up" : "Janela de Aviso",
+    "sec" : "seg.",
     "min" : "mínimo",
     "hours" : "horas",
     "days" : "dias",
     "week" : "semana",
-    "Before" : "Antes",
-    "After" : "Depois",
-    "Start" : "Iniciar",
-    "End" : "Fim",
+    "before" : "antes",
+    "start" : "Inicio",
+    "end" : "fim",
+    "Editing reminders of uknown type not supported." : "Não é suportada a edição de lembretes de tipo desconhecido.",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Successfully imported" : "Importado com sucesso",
     "Partially imported, 1 failure" : "Parcialmente importado, 1 erro",
     "Partially imported, {n} failures" : "Parcialmente importado, {n} erros",
     "Audio alarm" : "Alarme áudio",
-    "Pop-up" : "Aparecer",
+    "Pop-up" : "Janela de Aviso",
     "E-Mail" : "Correio Eletrónico",
     "{type} {time} before the event starts" : "{type} {time} antes do evento começar",
     "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
@@ -77,53 +63,63 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} no final do evento",
     "{type} at {time}" : "{type} às {time}",
     "{calendar} shared by {owner}" : "{calendar} partilhado por {owner}",
+    "Title of the Event" : "Título do Evento",
+    "starts" : "começa",
+    "ends" : "termina",
+    "All day Event" : "Evento todo o dia",
+    "Location" : "Localização:",
+    "Delete" : "Eliminar",
+    "Cancel" : "Cancelar",
+    "More ..." : "Mais...",
+    "Create" : "Criar",
+    "Update" : "Atualizar",
+    "Close" : "Fechar",
+    "Description" : "Descrição",
+    "Export" : "Exportar",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um erro próximo da fonte, o calendário atualmente não consegue dar suporte para a função de transporte do recurso.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor, contacte o seu administrador e peça-lhe para desativar a opção de configuração \"asset-pipeline.enabled\".",
     "Day" : "Dia",
     "Week" : "Semana",
     "Month" : "Mês",
     "Today" : "Hoje",
-    "Share Calendar" : "Partilhar calendário",
+    "Share Calendar" : "Partilhar Calendário",
+    "More" : "Mais",
+    "Edit" : "Editar",
+    "CalDAV" : "CalDAV",
     "group" : "grupo",
     "New Calendar" : "Novo Calendário",
-    "Create" : "Criar",
     "Subscriptions" : "Subscrições",
     "New Subscription" : "Nova Subscrição",
-    "Url" : "Link",
+    "Url" : "Url",
     "Edit event" : "Editar evento",
-    "Delete Event" : "Apagar Evento",
-    "Save Event" : "Salvar Evento",
+    "Delete Event" : "Eliminar Evento",
+    "Save Event" : "Guardar Evento",
     "Time" : "Tempo",
     "Type" : "Tipo",
     "Relative" : "Relativo",
     "Absolute" : "Absoluto",
-    "Date" : "Data",
     "Repeat" : "Repetir",
     "times every" : "vezes a cada",
     "Add" : "Adicionar",
-    "Please add your email address in the personal settings in order to add attendees." : "Por favor adicione o seu endereço de email nas configurações pessoais de modo a adicionar participantes.",
-    "Title of the Event" : "Título do evento",
+    "E-Mail address of attendee" : "Endereço de e-mail do participante",
+    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione o seu endereço de e-mail nas configurações pessoais para poder adicionar participantes.",
     "from" : "de",
     "to" : "para",
-    "All day Event" : "Evento todo o dia",
-    "Location" : "Localização:",
-    "starts" : "começa",
-    "ends" : "acaba",
-    "Delete" : "Eliminar",
-    "Cancel" : "Cancelar",
-    "More ..." : "Mais ...",
-    "Update" : "Actualizar",
-    "Close" : "Fechar",
-    "Interval" : "Intervalo",
-    "Description" : "Descrição",
-    "Export" : "Exportar",
+    "This event's repeating rule is not supported yet." : "A regra de repetição deste evento ainda não é suportada.",
+    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas será adicionado nas atualizações subsequentes.",
+    "Reset repeating rule" : "Reiniciar a regra de repetição",
+    "Repeat every ..." : "Repetir a cada... ",
+    "end repeat ..." : "terminar repetição...",
+    "times" : "vezes",
     "Import Calendars" : "Importar Calendários",
     "Import canceled" : "Importação cancelada",
-    "Analyzing calendar" : "Analisando calendário",
+    "Analyzing calendar" : "A analisar o calendário",
     "The file contains objects incompatible with the selected calendar" : "O ficheiro contém objetos incompatíveis com o calendário selecionado",
     "New calendar" : "Novo calendário",
     "Import scheduled" : "Importação agendada",
-    "Settings" : "Definições",
+    "Settings" : "Configurações",
     "Import calendar" : "Importar calendário",
-    "No Calendars selected for import" : "Nenhum Calendário selecionado para importação",
+    "No Calendars selected for import" : "Sem Calendários selecionados para importar",
     "Primary CalDAV address" : "Endereço principal CalDAV",
     "iOS/OS X CalDAV address" : "iOS/OS X endereço CalDAV"
 },
