@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Календарь",
-    "New event" : "Новое событие",
-    "Global" : "Основные",
-    "None" : "Отсутствует",
-    "Attendees" : "Участники",
-    "Reminders" : "Напоминания",
-    "Does not repeat" : "Не повторяется",
-    "Daily" : "Ежедневно",
-    "Weekly" : "Еженедельно",
-    "Every Weekday" : "По будням",
-    "Bi-weekly" : "Раз в две недели",
-    "Monthly" : "Каждый месяц",
-    "Yearly" : "Каждый год",
-    "never" : "никогда",
-    "by occurances" : "по случаю",
-    "by date" : "по дате",
-    "by monthday" : "по дню месяца",
-    "by weekday" : "по дню недели",
-    "by events date" : "по дате событий",
-    "by yearday(s)" : "по дням недели",
-    "by week no(s)" : "по номеру недели",
-    "by day and month" : "по дню и месяцу",
-    "Monday" : "Понедельник",
-    "Tuesday" : "Вторник",
-    "Wednesday" : "Среда",
-    "Thursday" : "Четверг",
-    "Friday" : "Пятница",
-    "Saturday" : "Суббота",
-    "Sunday" : "Воскресенье",
-    "Other" : "Другой",
     "Individual" : "Индивидуально",
     "Group" : "Группа",
     "Resource" : "Ресурс",
@@ -39,9 +10,23 @@ OC.L10N.register(
     "Required" : "Требуется",
     "Optional" : "Не обязательно",
     "Does not attend" : "Без посещения",
+    "New event" : "Новое событие",
+    "Attendees" : "Участники",
+    "Reminders" : "Напоминания",
+    "Repeating" : "Повторение",
     "When shared show full event" : "Показывать подробное событие при размещении в общем доступе",
     "When shared show only busy" : "Показывать занятость при размещении в общем доступе",
     "When shared hide this event" : "Скрыть это событие при размещении в общем доступе",
+    "Please add a title!" : "Пожалуйста добавьте заголовок!",
+    "Please select a calendar!" : "Пожалуйста выберите календарь!",
+    "Global" : "Основные",
+    "None" : "Отсутствует",
+    "Every day" : "Каждый день",
+    "Every week" : "Каждую неделю",
+    "Every month" : "Каждый месяц",
+    "Every year" : "Каждый год",
+    "never" : "никогда",
+    "after" : "после",
     "At time of event" : "Время события",
     "5 minutes before" : "За 5 минут до начала",
     "10 minutes before" : "За 10 минут до начала",
@@ -58,10 +43,6 @@ OC.L10N.register(
     "hours" : "часов",
     "days" : "дней",
     "week" : "неделя",
-    "Before" : "До",
-    "After" : "После",
-    "Start" : "Начало",
-    "End" : "Окончание",
     "Week {number} of {year}" : "{number} неделя {year} года",
     "Successfully imported" : "Успешно импортировано",
     "Partially imported, 1 failure" : "Частично импортировано, 1 ошибка",
@@ -77,14 +58,29 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} в момент окончания события",
     "{type} at {time}" : "{type} в {time}",
     "{calendar} shared by {owner}" : "{calendar} опубликован пользователем {owner}",
+    "Title of the Event" : "Название события",
+    "starts" : "начинается",
+    "ends" : "заканчивается",
+    "All day Event" : "Событие на весь день",
+    "Location" : "Местоположение",
+    "Delete" : "Удалить",
+    "Cancel" : "Отмена",
+    "More ..." : "Больше ...",
+    "Create" : "Создать",
+    "Update" : "Обновить",
+    "Close" : "Закрыть",
+    "Description" : "Описание",
+    "Export" : "Экспорт",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Пожалуйста свяжитесь с администратором и попросите отключить опцию \"assep-pipeline.enabled\"",
     "Day" : "День",
     "Week" : "Неделя",
     "Month" : "Месяц",
     "Today" : "Сегодня",
     "Share Calendar" : "Поделиться календарем",
+    "More" : "Больше",
+    "Edit" : "Редактировать",
     "group" : "группа",
     "New Calendar" : "Новый Календарь",
-    "Create" : "Создать",
     "Subscriptions" : "Подписки",
     "New Subscription" : "Новая подписка",
     "Url" : "Url",
@@ -95,26 +91,17 @@ OC.L10N.register(
     "Type" : "Тип",
     "Relative" : "Относительное",
     "Absolute" : "Абсолютное",
-    "Date" : "Дата",
     "Repeat" : "Повтор",
     "times every" : "раз каждые",
     "Add" : "Добавить",
-    "Title of the Event" : "Название события",
+    "E-Mail address of attendee" : "Адрес электронной почты участника",
     "from" : "из",
     "to" : "до",
-    "All day Event" : "Событие на весь день",
-    "Location" : "Местоположение",
-    "starts" : "начинается",
-    "ends" : "заканчивается",
-    "Delete" : "Удалить",
-    "Cancel" : "Отмена",
-    "More ..." : "Больше ...",
-    "Update" : "Обновить",
-    "Close" : "Закрыть",
-    "Interval" : "Интервал",
-    "Description" : "Описание",
-    "Export" : "Экспорт",
+    "Reset repeating rule" : "Сбросить правила повтора",
+    "Repeat every ..." : "Повторять каждые ...",
+    "end repeat ..." : "конец повтора ...",
     "Import Calendars" : "Импорт календарей",
+    "Import canceled" : "Импорт отменён",
     "Analyzing calendar" : "Анализ календарей",
     "The file contains objects incompatible with the selected calendar" : "Файл содержит объекты, которые не совместимы с выбранным календарем",
     "New calendar" : "Новый календарь",
