@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Koledar",
-    "New event" : "Nov dogodek",
-    "Global" : "Splošno",
-    "None" : "Brez",
-    "Attendees" : "Udeleženci",
-    "Reminders" : "Opomniki",
-    "Does not repeat" : "Se ne ponavlja",
-    "Daily" : "Dnevno",
-    "Weekly" : "Tedensko",
-    "Every Weekday" : "Vsak dan v tednu",
-    "Bi-weekly" : "Dvakrat tedensko",
-    "Monthly" : "Mesečno",
-    "Yearly" : "Letno",
-    "never" : "nikoli",
-    "by occurances" : "po pojavljanju",
-    "by date" : "po datumu",
-    "by monthday" : "po dnevu v mesecu",
-    "by weekday" : "po dnevu tedna",
-    "by events date" : "po datumu dogodka",
-    "by yearday(s)" : "po številu let",
-    "by week no(s)" : "po številki tednu",
-    "by day and month" : "po dnevu in mesecu",
-    "Monday" : "ponedeljek",
-    "Tuesday" : "torek",
-    "Wednesday" : "sreda",
-    "Thursday" : "četrtek",
-    "Friday" : "petek",
-    "Saturday" : "sobota",
-    "Sunday" : "nedelja",
-    "Other" : "drugo",
     "Individual" : "Posamezno",
     "Group" : "Skupina",
     "Resource" : "Vir",
@@ -39,9 +10,24 @@ OC.L10N.register(
     "Required" : "Zahtevano",
     "Optional" : "Izbirno",
     "Does not attend" : "Ni udeleženec",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ni mogoče določiti časovnega pasu ({tz}), zato bo prikazan čas UTC",
+    "New event" : "Nov dogodek",
+    "Attendees" : "Udeleženci",
+    "Reminders" : "Opomniki",
+    "Repeating" : "Ponavljanje",
     "When shared show full event" : "Če je v souporabi, pokaži celoten dogodek",
     "When shared show only busy" : "Če je v souporabi, pokaži le podatek o časovni zadržanosti",
     "When shared hide this event" : "Če je v souporabi, skrij ta dogodek",
+    "Please add a title!" : "Dodajte naslov!",
+    "Please select a calendar!" : "Izberite koledar!",
+    "Global" : "Splošno",
+    "None" : "Brez",
+    "Every day" : "Vsak dan",
+    "Every week" : "Vsak teden",
+    "Every month" : "Vsak mesec",
+    "Every year" : "Vsako leto",
+    "never" : "nikoli",
+    "after" : "po",
     "At time of event" : "Ob času dogodka",
     "5 minutes before" : "5 minut prej",
     "10 minutes before" : "10 minut prej",
@@ -58,10 +44,10 @@ OC.L10N.register(
     "hours" : "ur",
     "days" : "dni",
     "week" : "teden",
-    "Before" : "Pred",
-    "After" : "Po",
-    "Start" : "Začetek",
-    "End" : "Konec",
+    "before" : "pred",
+    "start" : "začetek",
+    "end" : "konec",
+    "Editing reminders of uknown type not supported." : "Urejanje opomnikov neznane vrste ni podprto.",
     "Week {number} of {year}" : "{number}. teden leta {year}",
     "Successfully imported" : "Uvoz uspešno končan",
     "Partially imported, 1 failure" : "Delno uvoženo, zaznana je 1 napaka",
@@ -77,14 +63,31 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} ob koncu dogodka",
     "{type} at {time}" : "{type} ob {time}",
     "{calendar} shared by {owner}" : "{calendar} je objavila oseba {owner}",
+    "Title of the Event" : "Naslov dogodka",
+    "starts" : "začetek",
+    "ends" : "konec",
+    "All day Event" : "Celodnevni dogodek",
+    "Location" : "Mesto",
+    "Delete" : "Izbriši",
+    "Cancel" : "Prekliči",
+    "More ..." : "Več ...",
+    "Create" : "Ustvari",
+    "Update" : "Posodobi",
+    "Close" : "Zapri",
+    "Description" : "Opis",
+    "Export" : "Izvozi",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Zaradi znanega hrošča v koledarju trenutno ni mogoča podpora zmožnosti skrčenja kode javascript in CSS.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Stopite v stik s sistemskim skrbnikom oziroma onemogočite nastavitev \"asset-pipeline.enabled\"",
     "Day" : "Dan",
     "Week" : "Teden",
     "Month" : "Mesec",
     "Today" : "Danes",
     "Share Calendar" : "Omogoči souporabo koledarja",
+    "More" : "Več",
+    "Edit" : "Uredi",
+    "CalDAV" : "CalDAV",
     "group" : "skupina",
     "New Calendar" : "Nov koledar",
-    "Create" : "Ustvari",
     "Subscriptions" : "Naročila",
     "New Subscription" : "Novo naročilo",
     "Url" : "Naslov URL",
@@ -95,26 +98,19 @@ OC.L10N.register(
     "Type" : "Vrsta",
     "Relative" : "Relativno",
     "Absolute" : "Absolutno",
-    "Date" : "Datum",
     "Repeat" : "Ponovi",
-    "times every" : "krat, vsakič",
+    "times every" : "krat vsakih",
     "Add" : "Dodaj",
+    "E-Mail address of attendee" : "Elektronski naslov udeleženca",
     "Please add your email address in the personal settings in order to add attendees." : "Dodati morate vaš elektronski naslov med osebne nastavitve, preden je mogoče dodajati udeležence",
-    "Title of the Event" : "Naslov dogodka",
     "from" : "od",
     "to" : "za",
-    "All day Event" : "Celodnevni dogodek",
-    "Location" : "Mesto",
-    "starts" : "začetek",
-    "ends" : "konec",
-    "Delete" : "Izbriši",
-    "Cancel" : "Prekliči",
-    "More ..." : "Več ...",
-    "Update" : "Posodobi",
-    "Close" : "Zapri",
-    "Interval" : "Časovni razmik",
-    "Description" : "Opis",
-    "Export" : "Izvozi",
+    "This event's repeating rule is not supported yet." : "Ponavljajoče pravilo tega dogodka še ni podprto.",
+    "Support for advanced rules will be added with subsequent updates." : "Podpora naprednejšim pravilom bo dodana z naslednjimi posodobitvami.",
+    "Reset repeating rule" : "Ponastavi ponavljajoče se pravilo",
+    "Repeat every ..." : "Ponovi na ..",
+    "end repeat ..." : "in ponovi ...",
+    "times" : "krat",
     "Import Calendars" : "Uvoz koledarjev",
     "Import canceled" : "Uvoz je preklican",
     "Analyzing calendar" : "Preučevanje koledarja",
