@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
-    "New event" : "Nytt event",
-    "Global" : "Global",
-    "None" : "Ingen",
-    "Attendees" : "Deltagare",
-    "Reminders" : "Påminnelser",
-    "Does not repeat" : "Upprepas inte",
-    "Daily" : "Dagligen",
-    "Weekly" : "Varje vecka",
-    "Every Weekday" : "Varje vardag",
-    "Bi-weekly" : "Varannan vecka",
-    "Monthly" : "Varje månad",
-    "Yearly" : "Årligen",
-    "never" : "aldrig",
-    "by occurances" : "efter tillfällen",
-    "by date" : "efter datum",
-    "by monthday" : "efter dag i månaden",
-    "by weekday" : "efter veckodag",
-    "by events date" : "efter händelsedatum",
-    "by yearday(s)" : "efter årsdag(ar)",
-    "by week no(s)" : "efter veckonummer",
-    "by day and month" : "efter dag och månad",
-    "Monday" : "Måndag",
-    "Tuesday" : "Tisdag",
-    "Wednesday" : "Onsdag",
-    "Thursday" : "Torsdag",
-    "Friday" : "Fredag",
-    "Saturday" : "Lördag",
-    "Sunday" : "Söndag",
-    "Other" : "Annat",
     "Individual" : "Individuell",
     "Group" : "Grupp",
     "Resource" : "Resurs",
@@ -39,9 +10,24 @@ OC.L10N.register(
     "Required" : "Krävs",
     "Optional" : "Valfritt",
     "Does not attend" : "Kommer inte att delta",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du är i en okänd tidszon ({tz}), faller tillbaka på UTC",
+    "New event" : "Nytt event",
+    "Attendees" : "Deltagare",
+    "Reminders" : "Påminnelser",
+    "Repeating" : "Repetera",
     "When shared show full event" : "När delad visa hela händelsen",
     "When shared show only busy" : "När delad visa endast upptagen",
     "When shared hide this event" : "När delad göm denna händelse",
+    "Please add a title!" : "Vänligen lägg till en titel!",
+    "Please select a calendar!" : "Vänligen välj en kalender!",
+    "Global" : "Global",
+    "None" : "Ingen",
+    "Every day" : "Varje dag",
+    "Every week" : "Varje vecka",
+    "Every month" : "Varje månad",
+    "Every year" : "Varje år",
+    "never" : "aldrig",
+    "after" : "efter",
     "At time of event" : "På tid för event",
     "5 minutes before" : "5 minuter före",
     "10 minutes before" : "10 minuter före",
@@ -49,6 +35,7 @@ OC.L10N.register(
     "30 minutes before" : "30 minuter före",
     "1 hour before" : "1 timme före",
     "2 hours before" : "2 timmar före",
+    "Custom" : "special",
     "Audio" : "Ljud",
     "E Mail" : "E-post",
     "Pop up" : "Pop-up ",
@@ -57,10 +44,10 @@ OC.L10N.register(
     "hours" : "timmar",
     "days" : "dagar",
     "week" : "vecka",
-    "Before" : "Före",
-    "After" : "Efter",
-    "Start" : "Starta",
-    "End" : "Slut",
+    "before" : "före",
+    "start" : "start",
+    "end" : "slut",
+    "Editing reminders of uknown type not supported." : "Att redigera påminnelser för okända typer stödjs inte.",
     "Week {number} of {year}" : "Vecka {number} av {year}",
     "Successfully imported" : "Lyckad importering",
     "Partially imported, 1 failure" : "Delvis importerad, 1 fel",
@@ -76,14 +63,31 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} vid händelsens slut",
     "{type} at {time}" : "{type} vid {time}",
     "{calendar} shared by {owner}" : "{calendar} delad utav {owner}",
+    "Title of the Event" : "Rubrik för händelsen",
+    "starts" : "börjar",
+    "ends" : "slutar",
+    "All day Event" : "Heldags evenemang",
+    "Location" : "Plats",
+    "Delete" : "Ta bort",
+    "Cancel" : "Avbryt",
+    "More ..." : "Mer ...",
+    "Create" : "Skapa",
+    "Update" : "Uppdatera",
+    "Close" : "Stäng",
+    "Description" : "Beskrivning",
+    "Export" : "Exportera",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund utav en bug uppströms, så kan inte calendar ge någon support för asset pipeline funktionen.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Var god kontakta din administratör och be denne avaktivera \"asset-pipeline.enable\" inställningen.",
     "Day" : "Dag",
     "Week" : "Vecka",
     "Month" : "Månad",
     "Today" : "Idag",
     "Share Calendar" : "Dela kalender",
+    "More" : "Mer",
+    "Edit" : "Ändra",
+    "CalDAV" : "CalDAV",
     "group" : "Grupp",
     "New Calendar" : "Ny kalender",
-    "Create" : "Skapa",
     "Subscriptions" : "Prenumerationer",
     "New Subscription" : "Ny prenumeration",
     "Url" : "Url",
@@ -94,26 +98,21 @@ OC.L10N.register(
     "Type" : "Typ",
     "Relative" : "Relativ",
     "Absolute" : "Absolut",
-    "Date" : "Datum",
     "Repeat" : "Upprepa",
     "times every" : "gånger varje",
     "Add" : "Lägg till",
-    "Title of the Event" : "Rubrik för händelsen",
+    "E-Mail address of attendee" : "E-mailadress till deltagare",
+    "Please add your email address in the personal settings in order to add attendees." : "Vänligen lägg till din e-mailadress i personliga inställningar för att kunna lägga till deltagare",
     "from" : "från",
     "to" : "till",
-    "All day Event" : "Heldags evenemang",
-    "Location" : "Plats",
-    "starts" : "börjar",
-    "ends" : "slutar",
-    "Delete" : "Ta bort",
-    "Cancel" : "Avbryt",
-    "More ..." : "Mer ...",
-    "Update" : "Uppdatera",
-    "Close" : "Stäng",
-    "Interval" : "Hur ofta",
-    "Description" : "Beskrivning",
-    "Export" : "Exportera",
+    "This event's repeating rule is not supported yet." : "Detta events repeteringsregel stödjs inte ännu",
+    "Support for advanced rules will be added with subsequent updates." : "Support för advancerade regler kommer läggas till i senare uppdateringar.",
+    "Reset repeating rule" : "Radera repeteringsregeln",
+    "Repeat every ..." : "Repetera varje ...",
+    "end repeat ..." : "sluta repetera ...",
+    "times" : "gånger",
     "Import Calendars" : "Importera kalender",
+    "Import canceled" : "Importering avbruten",
     "Analyzing calendar" : "Analyserar kalender",
     "The file contains objects incompatible with the selected calendar" : "Filen innehåller objekt inkompatibla med den valda kalendern",
     "New calendar" : "Ny kalender",
