@@ -6,30 +6,9 @@ OC.L10N.register(
     "Global" : "ทั่วไป",
     "None" : "ไม่มี",
     "Attendees" : "ผู้เข้าร่วมกิจกรรม",
-    "Does not repeat" : "ไม่ต้องทำซ้ำ",
-    "Daily" : "รายวัน",
-    "Weekly" : "รายสัปดาห์",
-    "Every Weekday" : "ทุกวันหยุด",
-    "Bi-weekly" : "สัปดาห์ละสองครั้ง",
-    "Monthly" : "รายเดือน",
-    "Yearly" : "รายปี",
+    "Repeating" : "ทำซ้ำ",
+    "Custom" : "กำหนดเอง",
     "never" : "ไม่ต้องเลย",
-    "by occurances" : "โดยเหตุการณ์ที่เกิดขึ้น",
-    "by date" : "ตามวันที่",
-    "by monthday" : "จากเดือน",
-    "by weekday" : "จากสัปดาห์",
-    "by events date" : "ตามวันที่จัดกิจกรรม",
-    "by yearday(s)" : "ของเมื่อวานนี้",
-    "by week no(s)" : "โดยสัปดาห์(s)",
-    "by day and month" : "ตามวันและเดือน",
-    "Monday" : "วันจันทร์",
-    "Tuesday" : "วันอังคาร",
-    "Wednesday" : "วันพุธ",
-    "Thursday" : "วันพฤหัสบดี",
-    "Friday" : "วันศุกร์",
-    "Saturday" : "วันเสาร์",
-    "Sunday" : "วันอาทิตย์",
-    "Other" : "อื่นๆ",
     "Individual" : "ของแต่ละบุคคล",
     "Group" : "กลุ่ม",
     "Resource" : "ทรัพยากร",
@@ -45,7 +24,6 @@ OC.L10N.register(
     "30 minutes before" : "30 นาทีก่อนหน้านั้น",
     "1 hour before" : "1 ชั่วโมงก่อนหน้านั้น",
     "2 hours before" : "2 ชั่วโมงก่อนหน้านั้น",
-    "Custom" : "กำหนดเอง",
     "Audio" : "เสียง",
     "E Mail" : "อีเมล",
     "Pop up" : "ป๊อปอัพ",
@@ -88,7 +66,6 @@ OC.L10N.register(
     "Type" : "ประเภท",
     "Relative" : "เครื่องญาติ",
     "Absolute" : "สมบูรณ์",
-    "Date" : "วันที่",
     "Repeat" : "ทำซ้ำ",
     "times every" : "ทุกครั้ง",
     "Add" : "เพิ่ม",
@@ -101,7 +78,6 @@ OC.L10N.register(
     "Cancel" : "ยกเลิก",
     "Update" : "อัพเดท",
     "Close" : "ปิด",
-    "Interval" : "ช่วงเวลา",
     "Description" : "รายละเอียด",
     "Export" : "ส่งออก",
     "Import Calendars" : "นำเข้าปฏิทิน",
