@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "日历",
-    "New event" : "新事件",
-    "Global" : "全局",
-    "None" : "不提醒",
-    "Attendees" : "参加者",
-    "Reminders" : "提醒",
-    "Does not repeat" : "不重复",
-    "Daily" : "每天",
-    "Weekly" : "每周",
-    "Every Weekday" : "每个工作日",
-    "Bi-weekly" : "每两周",
-    "Monthly" : "每月",
-    "Yearly" : "每年",
-    "never" : "从不",
-    "by occurances" : "按发生次数",
-    "by date" : "按日期",
-    "by monthday" : "按月的某天",
-    "by weekday" : "按星期的某天",
-    "by events date" : "按事件日期",
-    "by yearday(s)" : "按每年的某天",
-    "by week no(s)" : "按星期数",
-    "by day and month" : "按天和月份",
-    "Monday" : "星期一",
-    "Tuesday" : "星期二",
-    "Wednesday" : "星期三",
-    "Thursday" : "星期四",
-    "Friday" : "星期五",
-    "Saturday" : "星期六",
-    "Sunday" : "星期日",
-    "Other" : "其它",
     "Individual" : "个人",
     "Group" : "群组",
     "Resource" : "源",
@@ -39,9 +10,16 @@ OC.L10N.register(
     "Required" : "必填",
     "Optional" : "选填",
     "Does not attend" : "不参加",
+    "New event" : "新事件",
+    "Attendees" : "参加者",
+    "Reminders" : "提醒",
+    "Repeating" : "重复",
     "When shared show full event" : "共享时显示完整事件",
     "When shared show only busy" : "共享时仅显示进行中的事件",
     "When shared hide this event" : "共享时隐藏本事件",
+    "Global" : "全局",
+    "None" : "不提醒",
+    "never" : "从不",
     "At time of event" : "在事件发生的",
     "5 minutes before" : "5分钟前",
     "10 minutes before" : "10分钟前",
@@ -58,10 +36,6 @@ OC.L10N.register(
     "hours" : "小时",
     "days" : "天",
     "week" : "周",
-    "Before" : "之前",
-    "After" : "之后",
-    "Start" : "开始",
-    "End" : "结束",
     "Week {number} of {year}" : "{year}年的第{number}周",
     "Successfully imported" : "导入成功",
     "Partially imported, 1 failure" : "部分导入成功，1个失败",
@@ -77,14 +51,28 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} 事件结束时",
     "{type} at {time}" : "{type} {time}",
     "{calendar} shared by {owner}" : "{calendar} 由 {owner} 共享",
+    "Title of the Event" : "事件标题",
+    "starts" : "开始于",
+    "ends" : "结束于",
+    "All day Event" : "全天事件",
+    "Location" : "地点",
+    "Delete" : "删除",
+    "Cancel" : "取消",
+    "More ..." : "更多...",
+    "Create" : "创建",
+    "Update" : "更新",
+    "Close" : "关闭",
+    "Description" : "描述",
+    "Export" : "导出",
     "Day" : "天",
     "Week" : "星期",
     "Month" : "月",
     "Today" : "今天",
     "Share Calendar" : "共享日历",
+    "More" : "更多",
+    "Edit" : "编辑",
     "group" : "群组",
     "New Calendar" : "新建日历",
-    "Create" : "创建",
     "Subscriptions" : "订阅",
     "New Subscription" : "新的订阅",
     "Url" : "URL",
@@ -95,25 +83,11 @@ OC.L10N.register(
     "Type" : "类型",
     "Relative" : "相对",
     "Absolute" : "绝对",
-    "Date" : "日期",
     "Repeat" : "重复",
     "times every" : "次每",
     "Add" : "增加",
-    "Title of the Event" : "事件标题",
     "from" : "从",
     "to" : "到",
-    "All day Event" : "全天事件",
-    "Location" : "地点",
-    "starts" : "开始于",
-    "ends" : "结束于",
-    "Delete" : "删除",
-    "Cancel" : "取消",
-    "More ..." : "更多...",
-    "Update" : "更新",
-    "Close" : "关闭",
-    "Interval" : "间隔",
-    "Description" : "描述",
-    "Export" : "导出",
     "Import Calendars" : "导入日历",
     "Analyzing calendar" : "分析日历",
     "The file contains objects incompatible with the selected calendar" : "该文件包含的内容与选择的日历不兼容",
