@@ -2,33 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "日曆",
-    "New event" : "新活動",
-    "None" : "無",
-    "Attendees" : "出席者",
-    "Does not repeat" : "不重覆",
-    "Daily" : "每日",
-    "Weekly" : "每週",
-    "Every Weekday" : "平日",
-    "Bi-weekly" : "隔週",
-    "Monthly" : "每月",
-    "Yearly" : "每年",
-    "never" : "永不",
-    "by occurances" : "依次數",
-    "by date" : "由日期",
-    "by monthday" : "依月份日期",
-    "by weekday" : "由平日",
-    "by events date" : "由活動日期",
-    "by yearday(s)" : "依年份日期",
-    "by week no(s)" : "依週數",
-    "by day and month" : "由日與月",
-    "Monday" : "週一",
-    "Tuesday" : "週二",
-    "Wednesday" : "週三",
-    "Thursday" : "週四",
-    "Friday" : "週五",
-    "Saturday" : "週六",
-    "Sunday" : "週日",
-    "Other" : "其他",
+    "Individual" : "獨立",
     "Group" : "群組",
     "Resource" : "資源",
     "Room" : "房間",
@@ -36,8 +10,22 @@ OC.L10N.register(
     "Required" : "必填",
     "Optional" : "選填",
     "Does not attend" : "不參加",
+    "New event" : "新活動",
+    "Attendees" : "出席者",
+    "Reminders" : "提醒",
+    "Repeating" : "重覆中",
     "When shared show full event" : "分享的時候顯示完整活動",
     "When shared hide this event" : "分享的時候隱藏這個活動",
+    "Please add a title!" : "請加入標題！",
+    "Please select a calendar!" : "請選擇一個日曆！",
+    "Global" : "全域",
+    "None" : "無",
+    "Every day" : "每天",
+    "Every week" : "每週",
+    "Every month" : "每月",
+    "Every year" : "每年",
+    "never" : "永不",
+    "after" : "之後",
     "At time of event" : "活動當時",
     "5 minutes before" : "5 分鐘前",
     "10 minutes before" : "10 分鐘前",
@@ -54,10 +42,10 @@ OC.L10N.register(
     "hours" : "時",
     "days" : "天",
     "week" : "週",
-    "Before" : "前",
-    "After" : "後",
-    "Start" : "開始",
-    "End" : "結束",
+    "before" : "前",
+    "start" : "開始",
+    "end" : "結束",
+    "Editing reminders of uknown type not supported." : "不支援編輯未知類型的提醒",
     "Week {number} of {year}" : "{year} 的第 {number} 週",
     "Successfully imported" : "成功匯入",
     "Partially imported, 1 failure" : "部分匯入，1 個失敗",
@@ -73,14 +61,28 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} 活動結束時",
     "{type} at {time}" : "{type} 在 {time}",
     "{calendar} shared by {owner}" : "{calendar} 由 {owner} 分享",
+    "Title of the Event" : "活動標題",
+    "starts" : "開始",
+    "ends" : "結束",
+    "All day Event" : "全天活動",
+    "Location" : "地點",
+    "Delete" : "刪除",
+    "Cancel" : "取消",
+    "More ..." : "更多…",
+    "Create" : "建立",
+    "Update" : "更新",
+    "Close" : " 關閉",
+    "Description" : "描述",
+    "Export" : "匯出",
     "Day" : "日",
     "Week" : "週",
     "Month" : "月",
     "Today" : "今天",
     "Share Calendar" : "分享日曆",
+    "More" : "更多",
+    "Edit" : "編輯",
     "group" : "群組",
     "New Calendar" : "新日曆",
-    "Create" : "建立",
     "Subscriptions" : "訂閱",
     "New Subscription" : "新訂閱",
     "Url" : "網址",
@@ -91,24 +93,21 @@ OC.L10N.register(
     "Type" : "類型",
     "Relative" : "相對",
     "Absolute" : "絕對",
-    "Date" : "日期",
     "Repeat" : "重覆",
     "times every" : "次每",
     "Add" : "增加",
-    "Title of the Event" : "活動標題",
+    "E-Mail address of attendee" : "參加者的 email",
+    "Please add your email address in the personal settings in order to add attendees." : "請在個人設定頁面中設定您的 email 地址，才能新增參加者",
     "from" : "從",
     "to" : "至",
-    "All day Event" : "全天活動",
-    "Location" : "地點",
-    "Delete" : "刪除",
-    "Cancel" : "取消",
-    "More ..." : "更多…",
-    "Update" : "更新",
-    "Close" : " 關閉",
-    "Interval" : "間隔",
-    "Description" : "描述",
-    "Export" : "匯出",
+    "This event's repeating rule is not supported yet." : "還未支援此活動的重複規則",
+    "Support for advanced rules will be added with subsequent updates." : "進階的規則功能將會在未來的更新加入",
+    "Reset repeating rule" : "重設重複規則",
+    "Repeat every ..." : "重複循環：",
+    "end repeat ..." : "停止重複：",
+    "times" : "次",
     "Import Calendars" : "匯入日曆",
+    "Import canceled" : "已取消匯入",
     "Analyzing calendar" : "分析日曆",
     "The file contains objects incompatible with the selected calendar" : "這個檔案包含與選取的日曆不相容的物件",
     "New calendar" : "新日曆",
